const $ = jQuery;

class SyncProgression {
    constructor() {
        this.historyContainer = document.querySelector('.ysd-mapi-history-container');
        this.updateJobs = document.querySelector('.ysd-mapi__update-jobs');
        this.updateLog = document.querySelector('.ysd-mapi__update-log');
    }

    startInterval() {
        this.displaySyncProgression();
        this.displayNextSyncJob();
        setInterval(this.displaySyncProgression.bind(this), 5000);
        setInterval(this.displayNextSyncJob.bind(this), 5000);
    }

    displaySyncProgression() {
        var self = this;

        // Translations
        const {
            errorI18n,
            updateInfoStat,
            siteURL,
        } = dashboardI18n;

        $.ajax({
            url: siteURL + '/wp-json/ysd-mapi/v1/logs/crm_sync_status?last=1',
            error: function () {
                console.log(errorI18n);
            },
            success: function (data) {
                let dataKeys = Object.keys(data).sort(function (a, b) {
                    return b - a;
                });

                var data = data[dataKeys[0]];
                var index = data['index'] ?? '0';
                var total = data['total'] ?? '0';
                var media_progress = data['media_progress'] ?? '0';
                var media_total = data['media_total'] ?? '0';
                var status = data['status'] ?? '0';
                var log_messages = data['messages'] ?? [];
                var last_message = log_messages.length != '' ? log_messages[log_messages.length - 1].message : "/";

                // Calculate Percentages
                var total_percentage = Math.floor( index/total * 100);
                var media_percentage = Math.floor( media_progress/media_total * 100);
                var progressValue = self.updateJobs.querySelector('.ysd-mapi-job__progress-value .ysd-mapi-progress__bar');
                var progressValueLabel = self.updateJobs.querySelector('.ysd-mapi-job__progress-value .ysd-mapi-progress__bar-label');
                var mediaValue = self.updateJobs.querySelector('.ysd-mapi-job__media-value .ysd-mapi-progress__bar');
                var mediaValueLabel = self.updateJobs.querySelector('.ysd-mapi-job__media-value .ysd-mapi-progress__bar-label');

                // Update Jobs HTML
                if (self.updateJobs) {
                    if (!isNaN(total_percentage)) {
                        progressValueLabel.ariaValueNow = total_percentage;
                        progressValue.style = "--total-progress:" + total_percentage + "%";
                        progressValueLabel.innerHTML = 'Infinity' != total_percentage ? total_percentage + "%" + " (" + index + "/" + total + ")" : total_percentage;
                        if(100 !== total_percentage) {
                            progressValue.classList.add("ysd-mapi-progress__bar--active");
                        } else {
                            progressValue.classList.remove("ysd-mapi-progress__bar--active");
                        }
                    }
                    if (!isNaN(media_percentage)) {
                        mediaValueLabel.ariaValueNow = media_percentage;
                        mediaValue.style = "--media-progress:" + media_percentage + "%";
                        mediaValueLabel.innerHTML = 'Infinity' != media_percentage ? media_percentage + "%" + " (" + media_progress + "/" + media_total + ")" : media_percentage;
                        if(100 !== media_percentage) {
                            mediaValue.classList.add("ysd-mapi-progress__bar--active");
                        } else {
                            mediaValue.classList.remove("ysd-mapi-progress__bar--active");
                        }
                    }
                    self.updateJobs.querySelector('.ysd-mapi-job__status-value').innerHTML = updateInfoStat[status];
                    self.updateJobs.querySelector('.ysd-mapi-job__message-value').innerHTML = last_message;
                }

                self.updateLog.innerHTML = "";

                log_messages.slice().reverse().forEach(logItem => {
                    let date = new Date(logItem.timestamp * 1000);

                    let logItemNode = document.createElement("div");
                    logItemNode.classList.add('ysd-mapi__log-item');

                    if(logItem.severity_level)
                    {
                        logItemNode.classList.add('ysd-mapi__log-item-' + logItem.severity_level);
                    }

                    let timestampNode = document.createElement("div");
                    timestampNode.classList.add('ysd-mapi__log-timestamp');
                    let timestampText = document.createTextNode(date.toLocaleTimeString());
                    timestampNode.appendChild(timestampText);

                    let messageNode = document.createElement("div");
                    messageNode.classList.add('ysd-mapi__log-message');
                    let messageText = document.createTextNode(logItem.message);
                    messageNode.appendChild(messageText);

                    logItemNode.appendChild(timestampNode);
                    logItemNode.appendChild(messageNode);

                    self.updateLog.appendChild(logItemNode);

                });

                // dataKeys.forEach(function (value, index, array) {
                //     let date = new Date(value * 1000);
                //     let log = data[value];

                //     console.log(
                //        date.getFullYear() + '-' + date.getMonth() + '-' + date.getDay() + ' ' + date.getHours() + ':' + date.getMinutes() + ' progression: ' + log['progress']
                //     );
                // });
            },
            dataType: 'json',
            type: 'GET'
        });

    }

    displayNextSyncJob() {
        var self = this;

        // Translations
        const {
            errorI18n,
            noneI18n,
            siteURL,
        } = dashboardI18n;

        $.ajax({
            url: siteURL + '/wp-json/ysd-mapi/v1/cron-jobs/next/ysd_mapi_api_cron_hook',
            error: function () {
                console.log('<p>' + errorI18n + '</p>');
            },
            success: function (data) {
                if (data) {
                    var today = new Date().setHours(0, 0, 0, 0);
                    var cronDay = new Date(data * 1000).setHours(0, 0, 0, 0);

                    if (cronDay === today) {
                        var date = new Date(data * 1000).toLocaleTimeString();
                    } else {
                        var date = new Date(data * 1000).toLocaleString();
                    }
                } else {
                    date = noneI18n;
                }

                // Update Schedule HTML
                self.updateJobs.querySelector('.ysd-mapi-job__schedule-value').innerHTML = date;
            },
            dataType: 'json',
            type: 'GET'
        });
        
    }

}

export default SyncProgression;