const $ = jQuery;

// Translations
const {
    siteURL,
    dateI18n,
    statusI18n,
    redoI18n,
    timeI18n,
    mediaI18n,
    failedI18n,
    updatedI18n,
    addedI18n,
    updateInfoStat,
} = dashboardI18n;

class UpdateHistory {
    
    constructor(container, menuContainer) {
        this.container = container;
        this.menuContainer = menuContainer;
    }

    displayHistoryMenu()
    {
        $.ajax({
            url: siteURL + '/wp-json/ysd-mapi/v1/logs/',
            error: function (xhr, status) {
                console.log('Failed getting logs:\nstatus: ' + status + '\nresponse: ' + xhr.responseText);
            },
            success: function (data) {
                data = this.recursiveReverseSortKeys(data);

                var i = 0;

                let list = $.map(data, function(months, year) {
                    return $.map(months, function(days, month)
                    {
                        let active = i === 0 ? 'active' : '';
                        i++;

                        return `
                        <li class="ysd-mapi__logs-nav-item ${active}" data-logs-date-month="${month}" data-logs-date-year="${year}">
                            <span class="c-calender-icon"></span>${month} - ${year}
                        </li>
                        `;
                    }.bind(year)).join("");
                }).join("");

                this.menuContainer.innerHTML = `
                <ul>
                    ${list}
                </ul>
                `;

                let element = document.querySelector('.ysd-mapi__logs-nav-item.active');

                if(element)
                {
                    let year = element.getAttribute('data-logs-date-year');
                    let month = element.getAttribute('data-logs-date-month');

                    this.displayHistory(year, month);
                }
            }.bind(this),
            dataType: 'json',
            type: 'GET'
        });

    }

    displayHistory(year, month) {
        var self = this;

        $(self.container).empty();

        $.ajax({
            url: siteURL + '/wp-json/ysd-mapi/v1/logs/' + year + '/' + month,
            error: function (xhr, status) {
                console.log('Failed getting logs:\nstatus: ' + status + '\nresponse: ' + xhr.responseText);
            },
            success: function (data) {

                let jobs = [];

                let sortedTimestamps = self.reverseSortKeys(data);

                sortedTimestamps.forEach(timestamp => {
                    let job = {
                        timestamp: timestamp,
                        status: data[timestamp].status,
                    };

                    job.properties = self.mapMessagesToActions(data[timestamp].messages);

                    jobs.push(job);
                });

                let history_table_start = `
                    <div class="c-update-history__table">
                        <div class="c-update-history__head">
                            <div>`+dateI18n+`</div>
                            <div>`+statusI18n+`</div>
                            <div class="th-redo">`+redoI18n+`</div>
                        </div>
                `;

                let history_table_content = ``;
                
                $.each(jobs, function(key, job) {
                    history_table_content += self.jobTemplate(job);
                });

                let history_table_end = `</div>`;

                self.container.innerHTML = `
                    ${history_table_start}
                    ${history_table_content}
                    ${history_table_end}
                `;

                self.makeItClickable();

            },
            dataType: 'json',
            type: 'GET'
        });

    }

    jobTemplate(job)
    {
        let jobStart = `
            <div class="c-update-history__body">
                <div class="c-update-history__main">
                    <div class="c-update-history__td">${this.timeStampToDateString(job.timestamp)}</div>
                    <div class="c-update-history__td status-${job.status}">${updateInfoStat[job.status]}</div>
                    <div class="c-update-history__td"><div class="c-redo-history-icon"></div></div>
                </div>
        `;

        let jobProperties = ``;

        if(job.properties.length > 0)
        {
             jobProperties = `
                <div class="c-update-history__details">
                    <div class="c-update-history__head">
                        <div>`+dateI18n+`</div>
                        <div>`+statusI18n+`</div>
                        <div>ID</div>
                    </div>
                    ${
                        job.properties.map(this.propertyTemplate.bind(this)).join("")
                    }
                </div>
            `;
        }
        
        let jobEnd = `</div>`;

        return `
            ${jobStart}
            ${jobProperties}
            ${jobEnd}
        `;
        
    }

    propertyTemplate(property)
    {
        let propertyStart =  `
            <div class="c-update-history__item">
                <div class="c-update-history__item-details">
                    <div class="c-update-history__td">${this.timeStampToHourString(property.timestamp)}</div>
                    <div class="c-update-history__td ${property.style}">${property.status}</div>
                    <div class="c-update-history__td">${property.id}</div>
                </div>
        `;

        let propertyActions = ``;

        if(property.actions.length > 0)
        {
            propertyActions = `
                <div class="c-update-history__item-details__data-group">
                    <div class="c-update-history__head">
                        <div>`+timeI18n+`</div>
                        <div>`+statusI18n+`</div>
                        <div>`+mediaI18n+`</div>
                    </div>
                    ${
                        property.actions.map(this.actionTemplate.bind(this)).join("")
                    }
                </div>
            `;
        }

        let propertyEnd = `</div>`;

        return `
            ${propertyStart}
            ${propertyActions}
            ${propertyEnd}
        `;

    }

    actionTemplate(action)
    {
        return `
            <div class="c-update-history__item-details__data">
                <div class="c-update-history__td">${this.timeStampToHourString(action.timestamp)}</div>
                <div class="c-update-history__td ${action.style}">${action.status}</div>
                <div class="c-update-history__td">${action.attachment_id}</div>
            </div>
        `;

    }

    mapMessagesToActions(messages)
    {
        let properties = [];

        // First obtain all properties
        $.each(messages, function(key, message) {

            if(message.category === "property" && (message.severity_level === "error" || message.code === "property_import_updated" || message.code === "property_import_added"))
            {
                let status = '';
                let style = '';

                if(message.data)
                {
                    var id = message.data.property_id ?? null;
                }

                if(message.severity_level === "error")
                {
                    style = "status-fail";
                    status = failedI18n;
                }
                else if(message.code === "property_import_updated")
                {
                    style = "status-update";
                    status = updatedI18n;
                }
                else
                {
                    style = "status-added";
                    status = addedI18n;
                }

                let property = {
                    timestamp: message.timestamp,
                    id: id,
                    status: status,
                    style: style,
                    actions: [],
                };

                properties.push(property);
            }
        });

        // Add actions to properties
        $.each(messages, function(key, message) {
            // Only media actions
            if(message.category === "media" && (message.severity_level === "error" || message.code === "media_import_success"))
            {
                let status = '';
                let style = '';

                if(message.data)
                {
                    var attachment_id = message.data.attachment_id ?? null;
                    var property_id = message.data.property_id ?? null;
                }

                if(message.severity_level === "error")
                {
                    style = "status-fail";
                    status = failedI18n;
                }
                else
                {
                    style = "status-added";
                    status = addedI18n;
                }

                let action = {
                    timestamp: message.timestamp,
                    attachment_id: attachment_id,
                    property_id: property_id,
                    status: status,
                    style: style,
                };

                $.each(properties, function(key, property) {
                    if(property.id === action.property_id)
                    {
                        property.actions.push(action);
                    }
                });
            }
        });

        return properties;
        
    }

    makeItClickable()
    {
        
        var acc = document.getElementsByClassName("c-update-history__main");
        var panel = document.getElementsByClassName('c-update-history__details');

        for (var i = 0; i < acc.length; i++) {
            acc[i].onclick = function() {
                if ( this.nextElementSibling ) {
                    var setClasses = !this.classList.contains('active');
                    setClass(acc, 'active', 'remove');
                    setClass(panel, 'show', 'remove');
                    setClass(acc, 'muted', 'add');
                        
                    if (setClasses) {
                        this.classList.remove("muted");
                        this.classList.toggle("active");
                        this.nextElementSibling.classList.toggle("show");
                    } else {
                        setClass(acc, 'muted', 'remove');
                    }
                }
            }
        }
        
        var accSub = document.getElementsByClassName("c-update-history__item-details");
        var panelSub = document.getElementsByClassName('c-update-history__item-details__data-group');

        for (var i = 0; i < accSub.length; i++) {

            // console.log(accSub[i].nextElementSibling);
            if ( !accSub[i].nextElementSibling ) {
                accSub[i].classList.add('empty');
            }

            accSub[i].onclick = function() {
                if ( this.nextElementSibling ) {
                    var setClasses = !this.classList.contains('active');
                    setClass(accSub, 'active', 'remove');
                    setClass(panelSub, 'show', 'remove');
                    setClass(accSub, 'muted', 'add');

                    if (setClasses) {
                        this.classList.remove("muted");
                        this.classList.toggle("active");
                        this.nextElementSibling.classList.toggle("show");
                    } else {
                        setClass(accSub, 'muted', 'remove');
                    }
                }
            }
        }

        function setClass(els, className, fnName) {
            for (var i = 0; i < els.length; i++) {
                els[i].classList[fnName](className);
            }
        }

    }

    timeStampToDateString(timestamp)
    {
        let date = new Date(timestamp * 1000);

        return date.toLocaleString();

    }

    timeStampToHourString(timestamp)
    {
        let date = new Date(timestamp * 1000);

        let result = `${this.timeAddZero(date.getHours())}:${this.timeAddZero(date.getMinutes())}:${this.timeAddZero(date.getSeconds())}`

        return result;

    }

    recursiveReverseSortKeys(object)
    {
        if (typeof object != "object" || object instanceof Array)
        {
            return object;
        }

        var keys = Object.keys(object);

        keys.sort(function (a, b) {
            return b - a;
        });

        var reversSortedObject = {};
        for (var i = 0; i < keys.length; i++){
            reversSortedObject[keys[i]] = this.recursiveReverseSortKeys(object[keys[i]])
        }

        return reversSortedObject;

    }

    reverseSortKeys(object)
    {
        return Object.keys(object).sort(function (a, b) {
            return b - a;
        });

    }

    timeAddZero(i) {
        if (i < 10) {
            i = "0" + i;
        }
        return i;
    }

}

export default UpdateHistory;