<?php

use ysdmapi\includes\custom_fields\CustomField;

defined('ABSPATH') or die("No script kiddies please!");

add_action('admin_init', 'mapi_add_employee_meta_box');

function mapi_add_employee_meta_box() {
    add_meta_box('ysd_mapi_employee', __('Link with accountmanager ID', 'ysd-mapi'), 'mapi_employee_accountmanager', 'employee', 'side', 'default', null);
}

function mapi_employee_accountmanager($post) {
    $args = array(
        'post_type' => 'property',
        'posts_per_page' => -1,
        'meta_query' => array(
            array(
                'key' => 'accountmanager',
                'compare' => 'EXISTS',
            ),
            array(
                'key' => 'accountmanager',
                'value' => '',
                'compare' => '!=',
            ),
        ),
    );

    $query = new \WP_Query($args);
    $properties = $query->get_posts();

    $accountmanagers = [];

    foreach($properties as $property) {
        $accountmanager = get_post_meta($property->ID, 'accountmanager', true);

        if(!in_array($accountmanager, $accountmanagers)) {
            $accountmanagers[$accountmanager] = $accountmanager;
        }
    }

    $value = get_post_meta($post->ID, 'accountmanager', true);

    wp_nonce_field(basename(__FILE__), "meta-box-nonce");

    ?>

    <select id="accountmanager" name="accountmanager">
        <option value <?php echo !in_array($value, $accountmanagers) ? 'selected' : '' ?>><?= ' ' . __( '-- select an option --', YSD_MAPI_TEXT_DOMAIN ) . ' '; ?></option>

        <?php foreach($accountmanagers as $accountmanager) : ?>
            <option value="<?= $accountmanager ?>" <?php echo $value == $accountmanager ? 'selected' : ''?>><?= $accountmanager ?></option>
        <?php endforeach ?>
    </select>

    <?php
}

add_action('save_post', 'mapi_save_employee', 10, 3);
function mapi_save_employee($post_id, $post, $update) {

    if (!isset($_POST["meta-box-nonce"]) || !wp_verify_nonce($_POST["meta-box-nonce"], basename(__FILE__)))
        return $post_id;

    if(!current_user_can("edit_post", $post_id))
        return $post_id;

    if(defined("DOING_AUTOSAVE") && DOING_AUTOSAVE)
        return $post_id;

    $slug = "employee"; // post-type check
    if($slug != $post->post_type)
        return $post_id;

    // End location data group 

    /**
     * Save Fields
     */
    $accountmanager = '';

    if(isset($_POST["accountmanager"])) {
        $accountmanager = $_POST["accountmanager"];
    }
    
    update_post_meta($post_id, "accountmanager", $accountmanager);

}