<?php

use ysdmapi\includes\custom_fields\CustomField;

defined('ABSPATH') or die("No script kiddies please!");

add_action('admin_init', 'mapi_add_office_meta_box');

function mapi_add_office_meta_box() {
    add_meta_box('ysd_mapi_office', __('Link with agency ID', 'ysd-mapi'), 'mapi_office_agency', 'office', 'side', 'default', null);
}

function mapi_office_agency($post) {
    $args = array(
        'post_type' => 'property',
        'posts_per_page' => -1,
        'meta_query' => array(
            array(
                'key' => 'agency_id',
                'compare' => 'EXISTS',
            ),
            array(
                'key' => 'agency_id',
                'value' => '',
                'compare' => '!=',
            ),
        ),
    );

    $query = new \WP_Query($args);
    $properties = $query->get_posts();

    $agencies = [];

    foreach($properties as $property) {
        $agency = get_post_meta($property->ID, 'agency_id', true);

        if(!in_array($agency, $agencies)) {
            $agencies[$agency] = $agency;
        }
    }

    $value = get_post_meta($post->ID, 'agency_id', true);

    wp_nonce_field(basename(__FILE__), "meta-box-nonce");

    ?>

    <select id="agency" name="agency">
        <option value <?php echo !in_array($value, $agencies) ? 'selected' : '' ?>><?= ' ' . __( '-- select an option --', YSD_MAPI_TEXT_DOMAIN ) . ' '; ?></option>

        <?php foreach($agencies as $agency) : ?>
            <option value="<?= $agency ?>" <?php echo $value == $agency ? 'selected' : ''?>><?= $agency ?></option>
        <?php endforeach ?>
    </select>

    <?php
}

add_action('save_post', 'mapi_save_office', 10, 3);
function mapi_save_office($post_id, $post, $update) {

    if (!isset($_POST["meta-box-nonce"]) || !wp_verify_nonce($_POST["meta-box-nonce"], basename(__FILE__)))
        return $post_id;

    if(!current_user_can("edit_post", $post_id))
        return $post_id;

    if(defined("DOING_AUTOSAVE") && DOING_AUTOSAVE)
        return $post_id;

    $slug = "employee"; // post-type check
    if($slug != $post->post_type)
        return $post_id;

    // End location data group 

    /**
     * Save Fields
     */
    $agency = '';

    if(isset($_POST["agency"])) {
        $agency = $_POST["agency"];
    }
    
    update_post_meta($post_id, "agency", $agency);

}