jQuery(document).ready(function ($) {

    /**
     * Property Map
     */
    const {
        property,
        markerIcon,
        markerContent,
    } = mapData;
    
    const {
        propertyAll,
    } = mapDataAll;

    const searchQuery = property.number + ", " + property.address + ", " + property.city;

    /* Create searchcontrols */
    var OpenStreetMapProvider = window.GeoSearch.OpenStreetMapProvider;
    var provider = new OpenStreetMapProvider({});

    // Query for the address
    var getMap = document.getElementById('propertyMap');
    if (getMap) {
        provider.search({
            query: searchQuery
        })
        provider.search({
            query: searchQuery
        }).then(function (result) {
            if (result.length != '') {
                createMap(result);
            } else {
                $(getMap).remove();
            }
        });
    }

    function createMap(result) {

        // Log
        // console.log(result);
        // console.log(result[0].y);
        // console.log(result[0].x);

        // Center of the map
        if (result[0].y && result[0].x) {
            var center = [result[0].y, result[0].x];
        }

        // Create the map
        if (center) {
            var map = L.map(getMap, {
                center: center,
                zoom: 15,
                scrollWheelZoom: false
            });
        }

        // Set up the OSM layer
        if (map) {
            L.tileLayer(
                'http://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png', {
                    zoom: 2
                }).addTo(map);
        }

        // Add custom icon as marker
        if (markerIcon) {
            var myIcon = L.icon({
                iconUrl: markerIcon,
                iconSize: [38, 95],
                iconAnchor: [22, 94],
                popupAnchor: [-3, -76],
            });
        }

        // Add marker in given location
        if (myIcon) {
            var marker = L.marker(center, {
                icon: myIcon
            }).addTo(map);
        } else {
            var marker = L.marker(center).addTo(map);
        }

        // Create Popup
        if (marker) {
            marker.bindPopup(markerContent).openPopup();
        }

        var iconHouses = L.icon({
            iconUrl: 'https://raw.githubusercontent.com/pointhi/leaflet-color-markers/master/img/marker-icon-red.png',
            iconSize: [25, 40],
            iconAnchor: [22, 94],
            popupAnchor: [-3, -76],
        });
        
        let searchQueryAll;

        for(let i = 0; i < mapDataAll.length; i++){
            searchQueryAll = mapDataAll[i].propertyAll;

            $.get(location.protocol + '//nominatim.openstreetmap.org/search?format=json&q='+searchQueryAll, function(data){
                var lat = data[0].lat;
                var long = data[0].lon;
                var markerLocation = new L.LatLng(lat, long);

                if (iconHouses) {
                    var markerHouses = L.marker(markerLocation, {
                        icon: iconHouses
                    }).addTo(map);
                } else {
                    var markerHouses = L.marker(markerLocation).addTo(map);
                }

                // var markerHouses = new L.Marker(markerLocation);
                map.addLayer(markerHouses);

                var fullAddress = data[0].display_name;
                var addressArr = [];
                addressArr.push(fullAddress.split(", "));
                var address = addressArr[0][1] + ' ' + addressArr[0][0] + ', ' + addressArr[0][3];

                markerHouses.bindPopup(address).openPopup();
             });

             
        }
    }

    // Property Map
    const mapButton = document.getElementsByClassName("property-gallery__button--map");
    if (getMap && mapButton) {
        // Add smooth scrolling to map button
        $(mapButton).on('click', function (event) {
            // Make sure this.hash has a value before overriding default behavior
            if (this.hash !== "") {
                // Prevent default anchor click behavior
                event.preventDefault();
                // Store hash
                var hash = this.hash;
                // Using jQuery's animate() method to add smooth page scroll
                $('html, body').animate({
                    scrollTop: $(hash).offset().top - 100
                }, 800);
            }
        });
    }

});