<?php
/**
 * VC Shortcode - Property Featured
 *
 * @since 1.0
 */

class YSD_Mapi_Property_Featured_Shortcode {

	public function __construct() {
		add_shortcode( 'mapi_property_featured', array( $this, 'mapi_property_featured_shortcode' ) );
	}

	public function mapi_property_featured_shortcode( $atts ) {
		$options = shortcode_atts(
			array(
                'layout'          => 'list',
                'amount'          => '3',
                'amount_custom'   => '',
                'per_row'         => '3',
                'class'           => '',
                'type'            => '',
                'orderby'         => 'date',
                'order'           => 'DESC',
                'slider_auto'     => 'false',
                'slider_speed'    => '5000',
                'slider_loop'     => 'false',
                'slider_space'    => '16',
                'slider_pagi'     => false,
                'slider_navi'     => false,
                'slider_pagi_clr' => false,
                'slider_navi_clr' => false,
                'margin'          => '',
                'padding'         => '',
			),
			$atts,
			'mapi_property_featured'
		);

		$output = '';

        $amount        = ( 'custom' == $options['amount'] ) ? $options['amount_custom'] : $options['amount'];
        $id            = 'slider' != $options['layout'] ? ' id="properties"' : '' ;
        $class_grid    = 'slider' != $options['layout'] ? 'grid' : '' ;
        $class_swiper  = 'slider' == $options['layout'] ? 'swiper-slide' : '' ;
        $class_columns = 'slider' != $options['layout'] ? 'c-properties--columns-' . $options['per_row'] : 'c-properties--slider' ;

		// Add custom class
		$customCss = YSD_Mapi_Helpers::generate_css_class(
			array(
				'c-properties',
                $class_columns,
                $class_grid,
				$options['class'],
				$options['margin'],
				$options['padding'],
			),
			true
		);

		$filter_query = array(
			'post_type'      => 'property',
			'posts_per_page' => $amount,
			'orderby'        => $options['orderby'],
			'order'          => $options['order'],
		);

        $filter_query['meta_query'] = array(
            array(
                'key' => 'featured_property',
                'value' => '1',
                'compare' => '=',
            )
        );

        if ( !empty( $options['type'] ) ) {
            $args['meta_query'] = array(
                array(
                    'key' => 'sale_type',
                    'value' => $options['type'],
                )
            );
        }

		$the_query = new WP_query( $filter_query );

		if ( $the_query->have_posts() ) {

            if ( class_exists( 'Mapi_Property_Template' ) ) {
                $property = new Mapi_Property_Template();

                while ( $the_query->have_posts() ) {
                    $the_query->the_post();

                    $args = array(
                        'post_id'       =>  get_the_ID(),
                        'class'         =>  $class_swiper,
                    );

                    $property->setArgs( $args );

                    $output .= $property->render();

                }
                wp_reset_postdata();

            }

		}

        /*
         * Slider
         */
         if ( 'slider' == $options['layout'] ) {

            // Enqueue Swiper Style & Script
            wp_enqueue_style( 'swiper_style_core' );
            wp_enqueue_script( 'property-slider' );

            $pagi_clr = ($options['slider_pagi_clr']) ? 'style="color:'. $options['slider_pagi_clr'] .';"' : '';
            $navi_clr = ($options['slider_navi_clr']) ? 'style="color:'. $options['slider_navi_clr'] .';"' : '';

            $pagi = ($options['slider_pagi']) ? '<div class="swiper-pagination"'. $pagi_clr .'></div>' : '';
            $navi = ($options['slider_navi']) ? '<div class="swiper-button-prev"'. $navi_clr .'></div><div class="swiper-button-next"'. $navi_clr .'></div>' : '';

            // Wrap all output.
            $slider = sprintf(
                '<div class="swiper">
                    <div class="swiper-container" data-slides="%s" data-autoplay="%s" data-speed="%s" data-loop="%s" data-space="%s">
                        <div class="swiper-wrapper">%s</div>
                        %s
                        %s
                    </div>
                </div>',
                $options['per_row'],
                $options['slider_auto'],
                $options['slider_speed'],
                $options['slider_loop'],
                $options['slider_space'],
                $output,
                $pagi,
                $navi
            );

            $output = $slider;
        }

		// Wrap all output.
		$output = '<div'. $id .' class="' . $customCss . '">' . $output . '</div>';

		return $output;
	}

}

new YSD_Mapi_Property_Featured_Shortcode();