<?php

if ( ! function_exists( 'getPropertyPrice' ) ) {

    /**
     * Property Format - Price
     */
    function getPropertyPrice( $property ) {

        $price_type = getPropertyPriceType( $property );
        $price_formatted = getFormattedLocalePrice( $property );
        $sale_condition = getPropertySaleCondition( $property );

        $fallback = __( 'Price', YSD_MAPI_TEXT_DOMAIN );
        $price_type = ($price_type['value']) ? $price_type['value'] : $fallback;
        
        $data['label'] = $price_type;
        $data['value'] = $price_formatted;
        $data['value_label'] = $sale_condition;
        
        return $data;

    }
}

if ( ! function_exists( 'getPropertyPricePerArea' ) ) {

    /**
     * Property Format - Price
     */
    function getPropertyPricePerArea( $property ) {

        $price_type = getPropertyPriceType( $property );
        $price_formatted = getFormattedLocalePrice( $property, true );

        $volume_unit = get_option( 'ysd-mapi_realtor_property_unit', 'metric' );
        $volume_unit = ( 'imperial' === $volume_unit ) ? ' f²' : ' m²';
        $label_extra = __( 'per', YSD_MAPI_TEXT_DOMAIN );

        $fallback = __( 'Price', YSD_MAPI_TEXT_DOMAIN );
        $price_type = ($price_type['value']) ? $price_type['value'] : $fallback;

        $data['label'] = $price_type .' '. $label_extra . $volume_unit;
        $data['value'] = $price_formatted;
        
        return $data;

    }
}

if ( ! function_exists( 'getPropertyPriceType' ) ) {

    /**
     * Property Format - Price Type
     */
    function getPropertyPriceType( $property ) {

        $price_type = $property->price_type;

        switch($price_type) {
            case 'vraagprijs':
                $price_type = __( 'Asking price', YSD_MAPI_TEXT_DOMAIN );
                break;
            case 'huurprijs':
                $price_type = __( 'Rent price', YSD_MAPI_TEXT_DOMAIN );
                break;
            case 'koopsom':
                $price_type = __( 'Purchase price', YSD_MAPI_TEXT_DOMAIN );
                break;
        }

        $price_type ? $price_type : __( 'Price', YSD_MAPI_TEXT_DOMAIN );

        $data['label'] = __( 'Price type', YSD_MAPI_TEXT_DOMAIN );
        $data['value'] = $price_type;

        return $data;

    }
}

if ( ! function_exists( 'getPropertySaleType' ) ) {

    /**
     * Property Format - Sale Type
     */
    function getPropertySaleType( $property ) {

        $sale_type = $property->sale_type;

        switch($sale_type) {
            case 1:
                $sale_type = __( 'Buy', YSD_MAPI_TEXT_DOMAIN );
                break;
            case 2:
                $sale_type = __( 'Rent', YSD_MAPI_TEXT_DOMAIN );
                break;
        }
        
        $data['label'] = __( 'Sale type', YSD_MAPI_TEXT_DOMAIN );
        $data['value'] = $sale_type;
        
        return $data;

    }
}

if ( ! function_exists( 'getPropertySaleStatus' ) ) {

    /**
     * Property Format - Status
     */
    function getPropertySaleStatus( $property, $with_span = true ) {
        
        $sale_status = $property->sale_status;
        $num = $sale_status;

        switch ($sale_status) {
            case 1:
                $sale_status = __( 'For sale', YSD_MAPI_TEXT_DOMAIN );
                break;
            case 2:
                $sale_status = __( 'For rent', YSD_MAPI_TEXT_DOMAIN );
                break;
            case 3:
                $sale_status = __( 'Under offer', YSD_MAPI_TEXT_DOMAIN );
                break;
            case 4:
                $sale_status = __( 'Sold STC', YSD_MAPI_TEXT_DOMAIN );
                break;
            case 5:
                $sale_status = __( 'Rented STC', YSD_MAPI_TEXT_DOMAIN );
                break;
            case 6:
                $sale_status = __( 'Sold', YSD_MAPI_TEXT_DOMAIN );
                break;
            case 7:
                $sale_status = __( 'Rented', YSD_MAPI_TEXT_DOMAIN );
                break;
            case 8:
                $sale_status = __( 'Purchased', YSD_MAPI_TEXT_DOMAIN );
                break;
            case 9:
                $sale_status = __( 'Withdrawn', YSD_MAPI_TEXT_DOMAIN );
                break;
        }

        // With Span
        $value = false == $with_span ? $sale_status : '<span class="c-sale-status c-sale-status--'. $num .'">'. $sale_status .'</span>';

        $data['label'] = __( 'Status', YSD_MAPI_TEXT_DOMAIN );
        $data['value'] = $value;
        $data['num']   = $num;
        
        return $data;

    }
}

if ( ! function_exists( 'getPropertySoldOrRentedAt' ) ) {

    /**
     * Property Format - Sold or Rented at
     */
    function getPropertySoldOrRentedAt( $property ) {
        
        $date_format = "d-m-Y";
        $orgDate = $property->sold_or_rented_at;
        $newDate = date( $date_format, strtotime( $orgDate ) );

        $data['label'] = __( 'Sold or rented at', YSD_MAPI_TEXT_DOMAIN );
        $data['value'] = $newDate;
        
        return $data;

    }
}

if ( ! function_exists( 'getPropertyListedSince' ) ) {

    /**
     * Property Format - Listed Since @todo: change sold_since data
     */
    function getPropertyListedSince( $property ) {
        
        if ( ! function_exists( 'getFormattedValue' ) ) {
            return;
        }
        
        $listed_since = getFormattedValue( 'ListedSince', $property->sold_since );

        $data['label'] = __( 'Listed since', YSD_MAPI_TEXT_DOMAIN );
        $data['value'] = $listed_since;
        
        return $data;

    }
}

if ( ! function_exists( 'getPropertyPriceVat' ) ) {

    /**
     * Property Format - Price VAT @todo: fix the data
     */
    function getPropertyPriceVat( $property ) {
        
        $price_vat = $property->price_vat;

        $data['label'] = __( 'Price VAT', YSD_MAPI_TEXT_DOMAIN );
        $data['value'] = $price_vat;
        
        return $data;

    }
}

if ( ! function_exists( 'getPropertyAcceptance' ) ) {

    /**
     * Property Format - Acceptance
     */
    function getPropertyAcceptance( $property ) {
        
        $acceptance = $property->acceptance;
        switch ($acceptance) {
            case 'consulation':
                $acceptance = __( 'in consulation', YSD_MAPI_TEXT_DOMAIN );
                break;
            case 'in_consulation':
                $acceptance = __( 'in consulation', YSD_MAPI_TEXT_DOMAIN );
                break;
        }

        $data['label'] = __( 'Acceptance', YSD_MAPI_TEXT_DOMAIN );
        $data['value'] = $acceptance;
        
        return $data;

    }
}

if ( ! function_exists( 'getPropertyAcceptanceExplanation' ) ) {

    /**
     * Property Format - Acceptance Explanation
     */
    function getPropertyAcceptanceExplanation( $property ) {
        
        $acceptance_explanation = $property->acceptance_explanation;

        $data['label'] = __( 'Acceptance explanation', YSD_MAPI_TEXT_DOMAIN );
        $data['value'] = $acceptance_explanation;
        
        return $data;

    }
}

if ( ! function_exists( 'getPropertyOpenHouseStart' ) ) {

    /**
     * Property Format - Open House Start
     */
    function getPropertyOpenHouseStart( $property ) {
        
        $open_house_start = $property->open_house_start;

        $data['label'] = __( 'Open house start', YSD_MAPI_TEXT_DOMAIN );
        $data['value'] = $open_house_start;
        
        return $data;

    }
}

if ( ! function_exists( 'getPropertyOpenHouseEnd' ) ) {

    /**
     * Property Format - Open House End
     */
    function getPropertyOpenHouseEnd( $property ) {
        
        $open_house_end = $property->open_house_end;

        $data['label'] = __( 'Open house end', YSD_MAPI_TEXT_DOMAIN );
        $data['value'] = $open_house_end;
        
        return $data;

    }
}