<?php

if ( ! class_exists( 'Mapi_Property_Filters' ) ) {

    class Mapi_Property_Filters {
        
        /*
         * Property Filters
         */
        // public function property_filters( $langCode = '' ) {
            
        //     if($langCode == 'EN'){
        //         return $this->property_filters_en();
        //     }else{
        //         return $this->property_filters_default();
        //     }
        // }

        public static function get_current_language() {

            $current_lang = apply_filters( 'wpml_current_language', NULL );
            $current_lang = !empty( $current_lang ) ? strtoupper( $current_lang ) : 'NL';
            
            if ( ! empty( $current_lang ) ) {
                return self::get_filter( $current_lang );
            } else {
                return json_decode( self::get_default_nl(), JSON_PRETTY_PRINT );
            }

        }
        
        /*
         * Get Filter
         */
        public static function get_filter( $language = 'NL' ) {
            
            if ( empty( $language ) ) {
                return;
            }
            
            $get_language = get_option( 'ysd-mapi_filters_'. $language .'' );
            
            if ( ! empty( $get_language ) ) {
                return json_decode( $get_language, JSON_PRETTY_PRINT );
            } else {
                return json_decode( self::get_default_nl(), JSON_PRETTY_PRINT );
            }

        }

        public function property_filters_en(){
            return [
                "search" => [
                    "label" => __( 'Search', YSD_MAPI_TEXT_DOMAIN ),
                    "type" => "text",
                    "compare" => "LIKE"
                ],
                "city" => [
                    "meta" => "city",
                    "label" => __( 'City', YSD_MAPI_TEXT_DOMAIN ),
                    "type" => "dropdown",
                    "compare" => "=",
                    "emptyLabelMin" => __( 'Choose a city', YSD_MAPI_TEXT_DOMAIN ),
                ],
                "price" => [
                    "meta" => "price",
                    "label" => __( 'Price', YSD_MAPI_TEXT_DOMAIN ),
                    "type" => "minMaxDropdown",
                    "compare" => "=",
                    "meta_type" => "numeric",
                    "emptyLabelMin" => __( 'Minimal', YSD_MAPI_TEXT_DOMAIN ),
                    "emptyLabelMax" => __( 'Maximum', YSD_MAPI_TEXT_DOMAIN ),
                    "optionsMin" => [
                        "50000" => "50.000",
                        "100000" => "100.000",
                        "150000" => "150.000",
                        "200000" => "200.000",
                        "250000" => "250.000",
                        "300000" => "300.000",
                        "325000" => "325.000",
                        "350000" => "350.000",
                        "375000" => "375.000",
                        "400000" => "400.000",
                        "450000" => "450.000",
                        "500000" => "500.000",
                        "600000" => "600.000",
                        "700000" => "700.000",
                        "800000" => "800.000",
                        "900000" => "900.000",
                        "1000000" => "1.000.000",
                        "1500000" => "1.500.000",
                        "2000000" => "2.000.000",
                    ],
                    "optionsMax" => [
                        "50000" => "50.000",
                        "100000" => "100.000",
                        "150000" => "150.000",
                        "200000" => "200.000",
                        "250000" => "250.000",
                        "300000" => "300.000",
                        "325000" => "325.000",
                        "350000" => "350.000",
                        "375000" => "375.000",
                        "400000" => "400.000",
                        "450000" => "450.000",
                        "500000" => "500.000",
                        "600000" => "600.000",
                        "700000" => "700.000",
                        "800000" => "800.000",
                        "900000" => "900.000",
                        "1000000" => "1.000.000",
                        "1500000" => "1.500.000",
                        "2000000" => "2.000.000",
                    ],
                ],
                "sale_type" => [
                    "meta" => "sale_type",
                    "label" => __( 'Type', YSD_MAPI_TEXT_DOMAIN ),
                    "type" => "radio-group",
                    "compare" => "=",
                    "options" => [
                        "1" => __( 'Buy', YSD_MAPI_TEXT_DOMAIN ),
                        "2" => __( 'Rent', YSD_MAPI_TEXT_DOMAIN )
                    ],
                ],
                "sale_status" => [
                    "meta" => "sale_status",
                    "label" => __( 'Status', YSD_MAPI_TEXT_DOMAIN ),
                    "type" => "radio-group",
                    "compare" => "=",
                    "options" => [
                        "1" => __( 'For sale', YSD_MAPI_TEXT_DOMAIN ),
                        "2" => __( 'For rent', YSD_MAPI_TEXT_DOMAIN ),
                        "3" => __( 'Under offer', YSD_MAPI_TEXT_DOMAIN ),
                        "4" => __( 'Sold STC', YSD_MAPI_TEXT_DOMAIN ),
                        "5" => __( 'Rented STC', YSD_MAPI_TEXT_DOMAIN ),
                        "6" => __( 'Sold', YSD_MAPI_TEXT_DOMAIN ),
                        "7" => __( 'Rented', YSD_MAPI_TEXT_DOMAIN ),
                    ]
                ],
                "usable_area" => [
                    "meta" => "usable_area",
                    "label" => __( 'Living area', YSD_MAPI_TEXT_DOMAIN ),
                    "type" => "minMaxDropdown",
                    "compare" => "=",
                    "meta_type" => "numeric",
                    "emptyLabelMin" => __( 'Minimal', YSD_MAPI_TEXT_DOMAIN ),
                    "emptyLabelMax" => __( 'Maximum', YSD_MAPI_TEXT_DOMAIN ),
                    "optionsMin" => [
                        "25" => "25",
                        "50" => "50",
                        "75" => "75",
                        "100" => "100",
                        "150" => "150",
                        "200" => "200"
                    ],
                    "optionsMax" => [
                        "25" => "25",
                        "50" => "50",
                        "75" => "75",
                        "100" => "100",
                        "150" => "150",
                        "200" => "200"
                    ]
                ],
                "plot_area" => [
                    "meta" => "plot_area",
                    "label" => __( 'Plot size', YSD_MAPI_TEXT_DOMAIN ),
                    "type" => "minMaxDropdown",
                    "compare" => "=",
                    "meta_type" => "numeric",
                    "emptyLabelMin" => __( 'Minimal', YSD_MAPI_TEXT_DOMAIN ),
                    "emptyLabelMax" => __( 'Maximum', YSD_MAPI_TEXT_DOMAIN ),
                    "optionsMin" => [
                        "25" => "25",
                        "50" => "50",
                        "75" => "75",
                        "100" => "100",
                        "150" => "150",
                        "200" => "200"
                    ],
                    "optionsMax" => [
                        "25" => "25",
                        "50" => "50",
                        "75" => "75",
                        "100" => "100",
                        "150" => "150",
                        "200" => "200"
                    ]
                ],
                "volume_area" => [
                    "meta" => "volume_area",
                    "label" => __( 'Volume', YSD_MAPI_TEXT_DOMAIN ),
                    "type" => "minMaxDropdown",
                    "compare" => "=",
                    "meta_type" => "numeric",
                    "emptyLabelMin" => __( 'Minimal', YSD_MAPI_TEXT_DOMAIN ),
                    "emptyLabelMax" => __( 'Maximum', YSD_MAPI_TEXT_DOMAIN ),
                    "optionsMin" => [
                        "25" => "25",
                        "50" => "50",
                        "75" => "75",
                        "100" => "100",
                        "150" => "150",
                        "200" => "200"
                    ],
                    "optionsMax" => [
                        "25" => "25",
                        "50" => "50",
                        "75" => "75",
                        "100" => "100",
                        "150" => "150",
                        "200" => "200"
                    ]
                ],
                "number_of_bedrooms" => [
                    "meta" => "number_of_bedrooms",
                    "label" =>  __( 'Number of bedrooms', YSD_MAPI_TEXT_DOMAIN ),
                    "type" => "radio-group",
                    "compare" => ">=",
                    "options" => [
                        "1" => __( '1 bedroom', YSD_MAPI_TEXT_DOMAIN ),
                        "2" => __( '2 or more', YSD_MAPI_TEXT_DOMAIN ),
                        "3" => __( '3 or more', YSD_MAPI_TEXT_DOMAIN ),
                        "4" => __( '4 or more', YSD_MAPI_TEXT_DOMAIN ),
                        "5" => __( '5 or more', YSD_MAPI_TEXT_DOMAIN )
                    ]
                ],
                "number_of_rooms" => [
                    "meta" => "number_of_rooms",
                    "label" => __( 'Number of rooms', YSD_MAPI_TEXT_DOMAIN ),
                    "type" => "radio-group",
                    "compare" => ">=",
                    "options" => [
                        "1" => __( '1 room', YSD_MAPI_TEXT_DOMAIN ),
                        "2" => __( '2 or more', YSD_MAPI_TEXT_DOMAIN ),
                        "3" => __( '3 or more', YSD_MAPI_TEXT_DOMAIN ),
                        "4" => __( '4 or more', YSD_MAPI_TEXT_DOMAIN ),
                        "5" => __( '5 or more', YSD_MAPI_TEXT_DOMAIN )
                    ],
                ],
            ];
        }
        
        /*
         * Property Filters Default
         */
        public function get_default_nl() {
            return '{
                "search" : {
                    "label" : "Zoek",
                    "type" : "text",
                    "compare" : "LIKE"
                },
                "city" : {
                    "meta" : "city",
                    "label" : "Stad",
                    "type" : "dropdown",
                    "compare" : "=",
                    "emptyLabelMin" : "Kies een stad,
                },
                "price" : {
                    "meta" : "price",
                    "label" : "Prijs",
                    "type" : "minMaxDropdown",
                    "compare" : "=",
                    "meta_type" : "numeric",
                    "emptyLabelMin" : "Minimaal",
                    "emptyLabelMax" : "Maximaal",
                    "optionsMin" : {
                        "50000" : "50.000",
                        "100000" : "100.000",
                        "150000" : "150.000",
                        "200000" : "200.000",
                        "250000" : "250.000",
                        "300000" : "300.000",
                        "325000" : "325.000",
                        "350000" : "350.000",
                        "375000" : "375.000",
                        "400000" : "400.000",
                        "450000" : "450.000",
                        "500000" : "500.000",
                        "600000" : "600.000",
                        "700000" : "700.000",
                        "800000" : "800.000",
                        "900000" : "900.000",
                        "1000000" : "1.000.000",
                        "1500000" : "1.500.000",
                        "2000000" : "2.000.000",
                    },
                    "optionsMax" : {
                        "50000" : "50.000",
                        "100000" : "100.000",
                        "150000" : "150.000",
                        "200000" : "200.000",
                        "250000" : "250.000",
                        "300000" : "300.000",
                        "325000" : "325.000",
                        "350000" : "350.000",
                        "375000" : "375.000",
                        "400000" : "400.000",
                        "450000" : "450.000",
                        "500000" : "500.000",
                        "600000" : "600.000",
                        "700000" : "700.000",
                        "800000" : "800.000",
                        "900000" : "900.000",
                        "1000000" : "1.000.000",
                        "1500000" : "1.500.000",
                        "2000000" : "2.000.000",
                    },
                },
                "sale_type" : {
                    "meta" : "sale_type",
                    "label" : "Type",
                    "type" : "radio-group",
                    "compare" : "=",
                    "options" : {
                        "1" : "Koop",
                        "2" : "Huur"
                    },
                },
                "sale_status" : {
                    "meta" : "sale_status",
                    "label" : "Status",
                    "type" : "radio-group",
                    "compare" : "=",
                    "options" : {
                        "1" : "Te koop",
                        "2" : "Te huur",
                        "3" : "Onder bod",
                        "4" : "Verkocht o.v.",
                        "5" : "Verhuurd o.v.",
                        "6" : "Verkocht",
                        "7" : "Verhuurd",
                    }
                },
                "usable_area" : {
                    "meta" : "usable_area",
                    "label" : "Woonoppervlakte",
                    "type" : "minMaxDropdown",
                    "compare" : "=",
                    "meta_type" : "numeric",
                    "emptyLabelMin" : "Minimaal",
                    "emptyLabelMax" : "Maximaal",
                    "optionsMin" : {
                        "25" : "25",
                        "50" : "50",
                        "75" : "75",
                        "100" : "100",
                        "150" : "150",
                        "200" : "200"
                    },
                    "optionsMax" : {
                        "25" : "25",
                        "50" : "50",
                        "75" : "75",
                        "100" : "100",
                        "150" : "150",
                        "200" : "200"
                    }
                },
                "plot_area" : {
                    "meta" : "plot_area",
                    "label" : "Perceeloppervlakte",
                    "type" : "minMaxDropdown",
                    "compare" : "=",
                    "meta_type" : "numeric",
                    "emptyLabelMin" : "Minimaal",
                    "emptyLabelMax" : "Maximaal",
                    "optionsMin" : {
                        "25" : "25",
                        "50" : "50",
                        "75" : "75",
                        "100" : "100",
                        "150" : "150",
                        "200" : "200"
                    },
                    "optionsMax" : {
                        "25" : "25",
                        "50" : "50",
                        "75" : "75",
                        "100" : "100",
                        "150" : "150",
                        "200" : "200"
                    }
                },
                "volume_area" : {
                    "meta" : "volume_area",
                    "label" : "Inhoud",
                    "type" : "minMaxDropdown",
                    "compare" : "=",
                    "meta_type" : "numeric",
                    "emptyLabelMin" : "Minimaal",
                    "emptyLabelMax" : "Maximaal",
                    "optionsMin" : {
                        "25" : "25",
                        "50" : "50",
                        "75" : "75",
                        "100" : "100",
                        "150" : "150",
                        "200" : "200"
                    },
                    "optionsMax" : {
                        "25" : "25",
                        "50" : "50",
                        "75" : "75",
                        "100" : "100",
                        "150" : "150",
                        "200" : "200"
                    }
                },
                "number_of_bedrooms" : {
                    "meta" : "number_of_bedrooms",
                    "label" : "Aantal Slaapkamers",
                    "type" : "radio-group",
                    "compare" : ">=",
                    "options" : {
                        "1" : "1 slaapkamer",
                        "2" : "2 of meer",
                        "3" : "3 of meer",
                        "4" : "4 of meer",
                        "5" : "5 of meer"
                    }
                },
                "number_of_rooms" : {
                    "meta" : "number_of_rooms",
                    "label" : "Aantal Kamers",
                    "type" : "radio-group",
                    "compare" : ">=",
                    "options" : {
                        "1" : "1 kamer",
                        "2" : "2 of meer",
                        "3" : "3 of meer",
                        "4" : "4 of meer",
                        "5" : "5 of meer"
                    },
                },
            }';
        }
        /*
         * Property Filters Default
         */
        public function property_filters_rietbroek() {
            return [
                "aanbod"=> [
                    "meta"=> "offer",
                    "label"=> "Aanbod",
                    "type"=> "radio-group",
                    "compare"=> "=",
                    "options"=> [
                        "koop"=> "Koop",
                        "huur"=> "Huur"
                    ]
                ],
                "og"=> [
                    "meta"=> "og",
                    "label"=> "Object Type",
                    "type"=> "radio-group",
                    "compare"=> "=",
                    "options"=> [
                        "WONEN"=> "Wonen",
                        "BOG"=> "BOG"
                    ]
                ],
                "stad"=> [
                    "meta"=> "city",
                    "label"=> "Plaats",
                    "type"=> "checkbox-group",
                    "compare"=> "=",
                    "autofill"=> true,
                    "options"=> []
                ],
                "prijs"=> [
                    "meta"=> "price",
                    "label"=> "Prijs",
                    "type"=> "minMaxDropdown",
                    "compare"=> "=",
                    "meta_type"=> "numeric",
                    "emptyLabelMin"=> "Minimaal",
                    "emptyLabelMax"=> "Maximaal",
                    "defaultOptionMin"=> "Minimaal",
                    "defaultOptionMax"=> "Maximaal",
                    "optionsMin"=> [
                        // "ignore_filter"=> "0",
                        "50000"=> "50.000",
                        "100000"=> "100.000",
                        "150000"=> "150.000",
                        "200000"=> "200.000",
                        "250000"=> "250.000",
                        "300000"=> "300.000",
                        "325000"=> "325.000",
                        "350000"=> "350.000",
                        "375000"=> "375.000",
                        "400000"=> "400.000",
                        "450000"=> "450.000",
                        "500000"=> "500.000",
                        "600000"=> "600.000",
                        "700000"=> "700.000",
                        "800000"=> "800.000",
                        "900000"=> "900.000",
                        "1000000"=> "1.000.000",
                        "1500000"=> "1.500.000",
                        "2000000"=> "2.000.000"
                    ],
                    "optionsMax"=> [
                        "50000"=> "50.000",
                        "100000"=> "100.000",
                        "150000"=> "150.000",
                        "200000"=> "200.000",
                        "250000"=> "250.000",
                        "300000"=> "300.000",
                        "325000"=> "325.000",
                        "350000"=> "350.000",
                        "375000"=> "375.000",
                        "400000"=> "400.000",
                        "450000"=> "450.000",
                        "500000"=> "500.000",
                        "600000"=> "600.000",
                        "700000"=> "700.000",
                        "800000"=> "800.000",
                        "900000"=> "900.000",
                        "1000000"=> "1.000.000",
                        "1500000"=> "1.500.000",
                        "2000000"=> "2.000.000",
                        // "ignore_filter"=> "Geen maximum"
                    ]
                ],
                "sale_status" => [
                    "meta" => "sale_status",
                    "label" => "Transactiestatus",
                    "type" => "radio-group",
                    "compare" => "=",
                    "options" => [
                        "1" => "Te koop",
                        "2" => "Te huur",
                        "3" => "Onder bod",
                        "4" => "Verkocht o.v.",
                        "5" => "Verhuurd o.v.",
                        "6" => "Verkocht",
                        "7" => "Verhuurd",
                        "8"=> "Aangekocht"
                    ]                
                ],
                "woonopp"=> [
                    "meta"=> "usable_area",
                    "label"=> "Woonoppervlakte",
                    "type"=> "radio-group",
                    "compare"=> ">=",
                    "meta_type"=> "numeric",
                    "options"=> [
                        "50"=> "50 m² of meer",
                        "75"=> "75 m² of meer",
                        "100"=> "100 m² of meer",
                        "150"=> "150 m² of meer",
                        "250"=> "250 m² of meer"
                    ]
                ],
                "perceelopp"=> [
                    "meta"=> "plot_area",
                    "label"=> "Perceeloppervlakte",
                    "type"=> "radio-group",
                    "compare"=> ">=",
                    "meta_type"=> "numeric",
                    "options"=> [
                        "250"=> "250 m² of meer",
                        "500"=> "500 m² of meer",
                        "1000"=> "1.000 m² of meer",
                        "2500"=> "2.500 m² of meer",
                        "5000"=> "5.000 m² of meer"
                    ]
                ],
                "kamer"=> [
                    "meta"=> "number_of_rooms",
                    "label"=> "Aantal kamers",
                    "type"=> "radio-group",
                    "compare"=> ">=",
                    "meta_type"=> "numeric",
                    "options"=> [
                        "1"=> "1 kamer",
                        "2"=> "2 of meer",
                        "3"=> "3 of meer",
                        "4"=> "4 of meer",
                        "5"=> "5 of meer"
                    ]
                ],
                "slaapkamer"=> [
                    "meta"=> "number_of_bedrooms",
                    "label"=> "Aantal slaapkamers",
                    "type"=> "radio-group",
                    "compare"=> ">=",
                    "meta_type"=> "numeric",
                    "options"=> [
                        "1"=> "1 slaapkamer",
                        "2"=> "2 of meer",
                        "3"=> "3 of meer",
                        "4"=> "4 of meer",
                        "5"=> "5 of meer"
                    ]
                ],
                "type"=> [
                    "meta"=> "type",
                    "label"=> "Type",
                    "type"=> "checkbox-group",
                    "compare"=> "=",
                    "meta_type"=> "numeric",
                    "options"=> [
                        "1"=> "Woning",
                        "2"=> "Appartement",
                        "3"=> "Parkeerplaats",
                        "4"=> "Bouwgrond",
                        "5"=> "Kantoorruimte",
                        "6"=> "Bedrijfshal",
                        "7"=> "Overige privé woningen",
                        "8"=> "Overige BOG panden",
                        "9"=> "Andere panden"
                    ]
                ],
                "zoek"=> [
                    "label"=> "Zoek in omschrijving",
                    "type"=> "text",
                    "compare"=> "LIKE"
                ],
            ];
        }
    }

}