<?php

/**
 * MAIN Format Function
 */

if ( ! function_exists( 'getFormattedValue' ) ) {
    
    /**
     * Property Formatted Value
     */
    function getFormattedValue( $type, $value ) {

        if ( empty( $type ) ) {
            return;
        }

        // ListedSince
        if ( 'ListedSince' == $type ) {

            // Property Date
            $date_format = "d-m-Y H:i:s";
            // $value = "25-05-2021 13:45:00";
            
            $output = array();
            
            if ( ! empty( $value ) ) {
                // Specify the start date
                $date1 = date( $date_format, strtotime( $value ) );
                $date1 = date_create( $date1 );
                // Specify the end date
                $date2 = date( $date_format, strtotime( 'now' ) );
                $date2 = date_create( $date2 );
                // Calculate the number of weeks between two dates
                $date_diff_since = date_diff( $date1, $date2 );
                // Show the number of days between two dates
                $days_since = round($date_diff_since->days/7);
                // Do the magic!
                if ( $date_diff_since->y >= 1 ) {
                    $output[] = sprintf( _n( '%s year', '%s years', $date_diff_since->y, YSD_MAPI_TEXT_DOMAIN ), number_format_i18n( $date_diff_since->y ) );
                }
                if ( ( $date_diff_since->y >= 1 && $date_diff_since->m > 0 ) || $date_diff_since->m >= 2 ) {
                    $output[] = sprintf( _n( '%s month', '%s months', $date_diff_since->m , YSD_MAPI_TEXT_DOMAIN ), number_format_i18n( $date_diff_since->m ) );
                }
                if ( ($days_since > 0) && ($days_since < 8) ) {
                    $output[] = sprintf( _n( '%s week', '%s weeks', $days_since, YSD_MAPI_TEXT_DOMAIN ), number_format_i18n( $days_since ) );
                }
                if ( ($date_diff_since->days >= 1) && $days_since < 1 ) {
                    $output[] = sprintf( _n( '%s day', '%s days', $date_diff_since->d, YSD_MAPI_TEXT_DOMAIN ), number_format_i18n( $date_diff_since->d ) );
                }
                if ( ($date_diff_since->h >= 1 && $date_diff_since->h < 24) && $date_diff_since->days < 1 ) {
                    $output[] = sprintf( _n( '%s hour', '%s hours', $date_diff_since->h, YSD_MAPI_TEXT_DOMAIN ), number_format_i18n( $date_diff_since->h ) );
                } else if ( ($date_diff_since->i >= 1 && $date_diff_since->i < 60) && $date_diff_since->days < 1 ) {
                    $output[] = sprintf( _n( '%s minute', '%s minutes', $date_diff_since->i, YSD_MAPI_TEXT_DOMAIN ), number_format_i18n( $date_diff_since->i ) );
                } else if ( ($date_diff_since->i < 1) && $date_diff_since->days < 1 ) {
                    $output[] = sprintf( _n( '%s second', '%s seconds', $date_diff_since->s, YSD_MAPI_TEXT_DOMAIN ), number_format_i18n( $date_diff_since->s ) );
                }
            }
            
            $output = implode(', ', $output);

            return $output;
        }

        // EnergyInsulation
        if ( 'EnergyInsulation' == $type ) {
        
            $value = explode(', ', $value);
            $output = array();

            foreach($value as $case) {
                switch($case) {
                    case 'full' :
                        $output[] = __( 'full', YSD_MAPI_TEXT_DOMAIN );
                        break;
                    case 'roof':
                        $output[] = __( 'roof', YSD_MAPI_TEXT_DOMAIN );
                        break;
                    case 'floor':
                        $output[] = __( 'floor', YSD_MAPI_TEXT_DOMAIN );
                        break;
                    case 'double_glass':
                        $output[] = __( 'double glass', YSD_MAPI_TEXT_DOMAIN );
                        break;
                    case 'hr_glass':
                        $output[] = __( 'HR-glass', YSD_MAPI_TEXT_DOMAIN );
                        break;
                }
            }
            
            $output = implode(', ', $output);

            return $output;
        }

        // EnergyHeating
        if ( 'EnergyHeating' == $type ) {
        
            $value = explode(', ', $value);
            $output = array();

            foreach($value as $case) {
                switch($case) {
                    case 'heating_pump' :
                        $output[] = __( 'heating pump', YSD_MAPI_TEXT_DOMAIN );
                        break;
                }
            }
            
            $output = implode(', ', $output);

            return $output;
        }

        // ExteriorSpaceLocation
        if ( 'ExteriorSpaceLocation' == $type ) {
        
            $value = explode(', ', $value);
            $output = array();

            foreach($value as $case) {
                switch($case) {
                    case 'calm_road' :
                        $output[] = __( 'calm road', YSD_MAPI_TEXT_DOMAIN );
                        break;
                    case 'in_centrum' :
                        $output[] = __( 'in centrum', YSD_MAPI_TEXT_DOMAIN );
                        break;
                    case 'free_view' :
                        $output[] = __( 'free view', YSD_MAPI_TEXT_DOMAIN );
                        break;
                    case 'open_site' :
                        $output[] = __( 'open site', YSD_MAPI_TEXT_DOMAIN );
                        break;
                    case 'in_residential_area' :
                        $output[] = __( 'in residential area', YSD_MAPI_TEXT_DOMAIN );
                        break;
                    case 'by_water' :
                        $output[] = __( 'by water', YSD_MAPI_TEXT_DOMAIN );
                        break;
                    case 'by_waterway' :
                        $output[] = __( 'by waterway', YSD_MAPI_TEXT_DOMAIN );
                        break;
                    case 'covered_site' :
                        $output[] = __( 'covered site', YSD_MAPI_TEXT_DOMAIN );
                        break;
                }
            }
            
            $output = implode(', ', $output);

            return $output;
        }

        // ExteriorSpaceTypes
        if ( 'ExteriorSpaceTypes' == $type ) {
        
            $value = explode(', ', $value);
            $output = array();

            foreach($value as $case) {
                switch($case) {
                    case 'back' :
                        $output[] = __( 'backyard', YSD_MAPI_TEXT_DOMAIN );
                        break;
                    case 'front' :
                        $output[] = __( 'front yard', YSD_MAPI_TEXT_DOMAIN );
                        break;
                    case 'side' :
                        $output[] = __( 'side yard', YSD_MAPI_TEXT_DOMAIN );
                        break;
                }
            }
            
            $output = implode(', ', $output);

            return $output;
        }

        // ExteriorSpaceTypes
        if ( 'ExteriorSpaceTypes' == $type ) {
        
            $value = explode(', ', $value);
            $output = array();

            foreach($value as $case) {
                switch($case) {
                    case 'none' :
                        $output[] = __( 'none', YSD_MAPI_TEXT_DOMAIN );
                        break;
                }
            }
            
            $output = implode(', ', $output);

            return $output;
        }

        // GarageType
        if ( 'GarageType' == $type ) {
        
            $value = explode(', ', $value);
            $output = array();

            foreach($value as $case) {
                switch($case) {
                    case 'basement' :
                        $output[] = __( 'basement', YSD_MAPI_TEXT_DOMAIN );
                        break;
                    case 'parking' :
                        $output[] = __( 'parking', YSD_MAPI_TEXT_DOMAIN );
                        break;
                }
            }
            
            $output = implode(', ', $output);

            return $output;
        }

    }
}

/**
 * OTHER Format Functions
 */

if ( ! function_exists( 'getPropertyAddress' ) ) {
    
    /**
     * Property Format - Address
     */
    function getPropertyAddress( $property, $full = false ) {
        
        $address = $property->address_1;
        $house_number = $property->house_number;
        $house_number_addition = $property->house_number_addition;
        $city = $property->city;

        if ( $full ) {
            $address = $address .' '. $house_number .' '. $house_number_addition .' '. $city;
        } else {
            $address = $address .' '. $house_number .' '. $house_number_addition;
        }
        
        return $address;

    }
}

if ( ! function_exists( 'getPropertySaleCondition' ) ) {
    
    /**
     * Property Format - Sale Condition
     */
    function getPropertySaleCondition( $property ) {
        
        $sale_condition = $property->sale_condition;

        switch ($sale_condition) {
            case 1:
                $sale_condition = __( 'k.k.', YSD_MAPI_TEXT_DOMAIN );
                break;
            case 2:
                $sale_condition = __( 'v.o.n.', YSD_MAPI_TEXT_DOMAIN );
                break;
            case 3:
                $sale_condition = __( 'per month', YSD_MAPI_TEXT_DOMAIN );
                break;
            case 4:
                $sale_condition = __( 'quarterly', YSD_MAPI_TEXT_DOMAIN );
                break;
            case 5:
                $sale_condition = __( 'per half year', YSD_MAPI_TEXT_DOMAIN );
                break;
            case 6:
                $sale_condition = __( 'per year', YSD_MAPI_TEXT_DOMAIN );
                break;
            case 7:
                $sale_condition = __( 'per contract', YSD_MAPI_TEXT_DOMAIN );
                break;
            case 8:
                $sale_condition = __( 'per m² per month', YSD_MAPI_TEXT_DOMAIN );
                break;
            case 9:
                $sale_condition = __( 'per m² per year', YSD_MAPI_TEXT_DOMAIN );
                break;
        }
        
        return $sale_condition;

    }
}

if ( ! function_exists( 'getFormattedLocalePrice' ) ) {
    
    /**
     * Property Format - Formatted Locale Price
     */
    function getFormattedLocalePrice( $property, $per_area = false ) {
        // Valuta Settings
        $valuta = get_option( 'ysd-mapi_realtor_property_valuta', 'EUR' );

        // Price Per Area
        $price_per_area = ( ! empty( $property->price ) && ! empty( $property->usable_area ) && true == $per_area ) ? ceil( $property->price / $property->usable_area ) : '';
        $property_price = ( ! empty( $price_per_area ) ) ? $price_per_area : $property->price;
        $property_price = str_replace(array(".", ","), array("", ""), $property_price); // Remove all dots and comma's
        
        // Locale & Formatting
        $format = '';

        switch($valuta)
        {
            case 'USD':
                $symbol = '$';
                break;
            case 'GBP':
                $symbol = '£';
                break;
            default:
                $symbol = '€';
                break;
        }

        $format = ! empty( $property_price ) ? number_format( $property_price, 2, ',', '.' ) : '';
        $format = ! empty( $format ) ? $symbol . ' ' . $format : '';

        // Price Format
        $price = ( ! empty( $format ) && ! empty( $property_price ) ) ? $format : '';
        $price = ( true == $per_area ) ? str_replace( ',00', '', $price ) : str_replace( ',00', ',-', $price );
        
        // Price Output
        $output = '';
        if ( ! empty( $price ) ) {
            $output = $price;
        } else {
            $output = __( 'Price on request', YSD_MAPI_TEXT_DOMAIN );
        }
        
        return $output;

    }
}

if ( ! function_exists( 'getRealtorVolumeUnits' ) ) {
    
    /**
     * Property Format - Volume Units
     */
    function getRealtorVolumeUnits( $volume_type = 'square' ) {
        
        $output = '';
        $volume_unit = get_option( 'ysd-mapi_realtor_property_unit', 'metric' );
        
        if ( 'cubic' === $volume_type ) {
            $volume_type = '&sup3;';
        } else {
            $volume_type = '&sup2;';
        }
        
        if ( 'imperial' === $volume_unit ) {
            $output = 'f' . $volume_type;
        } else {
            $output = 'm' . $volume_type;
        }
        
        return $output;

    }
}

if ( ! function_exists( 'getFormatOptionLabel' ) ) {
    
    /**
     * Get the right Format of the Option Label
     */
    function getFormatOptionLabel( $type = null, $label = null ) {
        
        $output = '';

        // Fallback
        if ( empty( $type ) || empty( $label ) ) {
            $output = $label;
        }

        // Price
        if ( ! empty( $label ) && ( 'price' == $type ) ) {

            // Setting
            $valuta = get_option( 'ysd-mapi_realtor_property_valuta', 'EUR' );

            switch($valuta)
            {
                case 'USD':
                    $symbol = '$';
                    break;
                case 'GBP':
                    $symbol = '£';
                    break;
                default:
                    $symbol = '€';
                    break;
            }
            
            // Format
            $price = ( ! empty( $label ) ) ? preg_replace( '/[^0-9]/', '', $label ) : '';

            if( ! empty( $price ) )
            {
                $price = number_format( $price, 2, ',', '.' );
                $price = $symbol . ' ' . $price;
                $price = str_replace( ',00', ',-', $price );
            }

            // Return
            $output = ( ! empty( $price ) ) ? $price : '';

        }

        // Plot area, Usable area & Volume area
        if ( ! empty( $label ) && ( 'plot_area' == $type || 'usable_area' == $type || 'volume_area' == $type ) ) {

            // Setting
            $volume_unit = get_option( 'ysd-mapi_realtor_property_unit', 'metric' );
            
            // Format
            $volume_symbol = ( 'volume_area' == $type ) ? '³' :  '²';
            $volume = ( 'imperial' === $volume_unit ) ? $label . ' f'. $volume_symbol :  $label . ' m'. $volume_symbol;

            // Return
            $output = ( ! empty( $volume ) ) ? $volume : '';

        }
        
        // Final Return
        return $output;

    }
}