<?php

if ( ! class_exists( 'YSD_Mapi_Property_Data_Tables' ) ) {

    class YSD_Mapi_Property_Data_Tables {

        public function init() {
            ob_start();
            $output = '';

            $output .= $this->property_data_details_address_details();
            $output .= $this->property_data_details_transfer_of_ownership();
            $output .= $this->property_data_details_construction();
            $output .= $this->property_data_details_surface_areas_and_volume();
            $output .= $this->property_data_details_layout();
            $output .= $this->property_data_details_energy();
            $output .= $this->property_data_details_cadastral_data();
            $output .= $this->property_data_details_exterior_space();
            $output .= $this->property_data_details_storage_space();
            $output .= $this->property_data_details_garage();

            $output = ob_get_contents();
            ob_get_clean();
            return $output;
        }

        /**
         * Property render table.
         */
        public function render_property_table( $data, $name, $title ) {
            $html = '';
            if ( count( $data ) ) {
                $html .= '<div class="property-data-wrapper property-data-wrapper--'. $name .'" id="table-'. $name .'">';
                if ( $title ) {
                    $html .= '<h3 class="property-data-title">' . $title . '</h3>';
                }
                $html .= '<div class="property-data-table"><dl>';
                foreach ( $data as $row ) {
                    $value_label = ! empty ( $row['value_label'] ) ? ' '. $row['value_label'] : '';

                    $html .= '
                        <dt>' . $row['label'] . '</dt>
                        <dd>' . $row['value'] . $value_label . '</dd>
                    ';
                }
                $html .= '</dl></div>';
                $html .= '</div>';
            }
            return $html;
        }

        /**
         * Property Data Table - Transfer of ownership.
         */
        public function property_data_details_address_details( $data = array() ) {
            $data = array();
            $post_id = get_queried_object_id();
            $property = get_post( $post_id );
            if ( ! $property ) {
                return;
            }

            $title = __( 'Address Details', YSD_MAPI_TEXT_DOMAIN );
            $name  = 'address_datails';

            if ( ! empty( getPropertyStreetName( $property )['value'] ) ) {
                $data[] = getPropertyStreetName( $property );
            }
            if ( ! empty( getPropertyHouseNumber( $property )['value'] ) ) {
                $data[] = getPropertyHouseNumber( $property );
            }
            if ( ! empty( getPropertyZipcode( $property )['value'] ) ) {
                $data[] = getPropertyZipcode( $property );
            }
            if ( ! empty( getPropertyCity( $property )['value'] ) ) {
                $data[] = getPropertyCity( $property );
            }

            if ( ! empty( $data ) ) {
                echo $this->render_property_table( $data, $name, $title );
            }
        }

        /**
         * Property Data Table - Transfer of ownership.
         */
        public function property_data_details_transfer_of_ownership( $data = array() ) {
            
            $data = array();
            $post_id = get_queried_object_id();
            $property = get_post( $post_id );
            if ( ! $property ) {
                return;
            }

            $title = __( 'Transfer of ownership', YSD_MAPI_TEXT_DOMAIN );
            $name  = 'transfer_of_ownership';

            if ( ! empty( getPropertyPrice( $property )['value'] ) ) {
                $data[] = getPropertyPrice( $property );
            }
            if ( ! empty( getPropertyPricePerArea( $property )['value'] ) ) {
                $data[] = getPropertyPricePerArea( $property );
            }
            // if ( ! empty( getPropertyPriceType( $property )['value'] ) ) {
            //     $data[] = getPropertyPriceType( $property );
            // }
            // if ( ! empty( getPropertySaleType( $property )['value'] ) ) {
            //     $data[] = getPropertySaleType( $property );
            // }
            if ( ! empty( getPropertySaleStatus( $property )['value'] ) ) {
                $data[] = getPropertySaleStatus( $property, false );
            }
            if ( ! empty( getPropertyListedSince( $property )['value'] ) ) {
                $data[] = getPropertyListedSince( $property );
            }
            // if ( ! empty( getPropertySoldOrRentedAt( $property )['value'] ) ) {
            //     $data[] = getPropertySoldOrRentedAt( $property );
            // }
            if ( ! empty( getPropertyAcceptance( $property )['value'] ) ) {
                $data[] = getPropertyAcceptance( $property );
            }
            if ( ! empty( getPropertyAcceptanceExplanation( $property )['value'] ) ) {
                $data[] = getPropertyAcceptanceExplanation( $property );
            }
            // if ( ! empty( getPropertyOpenHouseStart( $property )['value'] ) ) {
            //     $data[] = getPropertyOpenHouseStart( $property );
            // }
            // if ( ! empty( getPropertyOpenHouseEnd( $property )['value'] ) ) {
            //     $data[] = getPropertyOpenHouseEnd( $property );
            // }

            if ( ! empty( $data ) ) {
                echo $this->render_property_table( $data, $name, $title );
            }
        }

        /**
         * Property Data Table - Construction
         */
        public function property_data_details_construction( $data = array() ) {

            $data = array();
            $post_id = get_queried_object_id();
            $property = get_post( $post_id );
            if ( ! $property ) {
                return;
            }

            $title = __( 'Construction', YSD_MAPI_TEXT_DOMAIN );
            $name  = 'construction';

            if ( ! empty( getPropertyType( $property )['value'] ) ) {
                $data[] = getPropertyType( $property );
            }
            if ( ! empty( getPropertyConstructionYear( $property )['value'] ) ) {
                $data[] = getPropertyConstructionYear( $property );
            }
            if ( ! empty( getPropertyBuildType( $property )['value'] ) ) {
                $data[] = getPropertyBuildType( $property );
            }
            if ( ! empty( getPropertyConstructionPeriod( $property )['value'] ) ) {
                $data[] = getPropertyConstructionPeriod( $property );
            }
            if ( ! empty( getPropertyUnderConstruction( $property )['value'] ) ) {
                $data[] = getPropertyUnderConstruction( $property );
            }

            if ( ! empty( $data ) ) {
                echo $this->render_property_table( $data, $name, $title );
            }
        }

        /**
         * Property Data Table - Surface areas and volume
         */
        public function property_data_details_surface_areas_and_volume( $data = array() ) {

            $data = array();
            $post_id = get_queried_object_id();
            $property = get_post( $post_id );
            if ( ! $property ) {
                return;
            }

            $title = __( 'Surface areas and volume', YSD_MAPI_TEXT_DOMAIN );
            $name  = 'surface-areas-and-volume';

            if ( ! empty( getPropertyUsableArea( $property )['value'] ) ) {
                $data[] = getPropertyUsableArea( $property );
            }
            if ( ! empty( getPropertyPlotArea( $property )['value'] ) ) {
                $data[] = getPropertyPlotArea( $property );
            }
            if ( ! empty( getPropertyVolumeArea( $property )['value'] ) ) {
                $data[] = getPropertyVolumeArea( $property );
            }

            if ( ! empty( $data ) ) {
                echo $this->render_property_table( $data, $name, $title );
            }
        }

        /**
         * Property Data Table - Layout
         */
        public function property_data_details_layout( $data = array() ) {

            $data = array();
            $post_id = get_queried_object_id();
            $property = get_post( $post_id );
            if ( ! $property ) {
                return;
            }

            $title = __( 'Layout', YSD_MAPI_TEXT_DOMAIN );
            $name  = 'layout';

            if ( ! empty( getPropertyBedrooms( $property )['value'] ) ) {
                $data[] = getPropertyBedrooms( $property );
            }
            if ( ! empty( getPropertyRooms( $property )['value'] ) ) {
                $data[] = getPropertyRooms( $property );
            }
            if ( ! empty( getPropertyBathrooms( $property )['value'] ) ) {
                $data[] = getPropertyBathrooms( $property );
            }
            if ( ! empty( getPropertyStories( $property )['value'] ) ) {
                $data[] = getPropertyStories( $property );
            }
            // if ( ! empty( getPropertyLocatedAtFloor( $property )['value'] ) ) {
            //     $data[] = getPropertyLocatedAtFloor( $property );
            // }
            if ( ! empty( getPropertyFacilities( $property )['value'] ) ) {
                $data[] = getPropertyFacilities( $property );
            }

            if ( ! empty( $data ) ) {
                echo $this->render_property_table( $data, $name, $title );
            }
        }

        /**
         * Property Data Table - Energy
         */
        public function property_data_details_energy( $data = array() ) {

            $data = array();
            $post_id = get_queried_object_id();
            $property = get_post( $post_id );
            if ( ! $property ) {
                return;
            }

            $title = __( 'Energy', YSD_MAPI_TEXT_DOMAIN );
            $name  = 'energy';

            if ( ! empty( getPropertyEnergyLabel( $property )['value'] ) ) {
                $data[] = getPropertyEnergyLabel( $property );
            }
            if ( ! empty( getPropertyEnergyIndex( $property )['value'] ) ) {
                $data[] = getPropertyEnergyIndex( $property );
            }
            if ( ! empty( getPropertyEnergyLabelEndDate( $property )['value'] ) ) {
                $data[] = getPropertyEnergyLabelEndDate( $property );
            }
            if ( ! empty( getPropertyEnergyInsulation( $property )['value'] ) ) {
                $data[] = getPropertyEnergyInsulation( $property );
            }
            if ( ! empty( getPropertyEnergyEpc( $property )['value'] ) ) {
                $data[] = getPropertyEnergyEpc( $property );
            }
            if ( ! empty( getPropertyEnergyHeating( $property )['value'] ) ) {
                $data[] = getPropertyEnergyHeating( $property );
            }
            if ( ! empty( getPropertyBoilerType( $property )['value'] ) ) {
                $data[] = getPropertyBoilerType( $property );
            }
            if ( ! empty( getPropertyBoilerYear( $property )['value'] ) ) {
                $data[] = getPropertyBoilerYear( $property );
            }
            if ( ! empty( getPropertyBoilerProperty( $property )['value'] ) ) {
                $data[] = getPropertyBoilerProperty( $property );
            }
            if ( ! empty( getPropertyBoilerCombi( $property )['value'] ) ) {
                $data[] = getPropertyBoilerCombi( $property );
            }

            if ( ! empty( $data ) ) {
                echo $this->render_property_table( $data, $name, $title );
            }
        }

        /**
         * Property Data Table - Cadastral data
         */
        public function property_data_details_cadastral_data( $data = array() ) {

            $data = array();
            $post_id = get_queried_object_id();
            $property = get_post( $post_id );
            if ( ! $property ) {
                return;
            }

            $title = __( 'Cadastral data', YSD_MAPI_TEXT_DOMAIN );
            $name  = 'cadastral_data';

            if ( ! empty( $data ) ) {
                echo $this->render_property_table( $data, $name, $title );
            }
        }

        /**
         * Property Data Table - Exterior space
         */
        public function property_data_details_exterior_space( $data = array() ) {

            $data = array();
            $post_id = get_queried_object_id();
            $property = get_post( $post_id );
            if ( ! $property ) {
                return;
            }

            $title = __( 'Exterior space', YSD_MAPI_TEXT_DOMAIN );
            $name  = 'exterior_space';

            if ( ! empty( getPropertyExteriorSpaceLocation( $property )['value'] ) ) {
                $data[] = getPropertyExteriorSpaceLocation( $property );
            }
            if ( ! empty( getPropertyExteriorSpaceTypes( $property )['value'] ) ) {
                $data[] = getPropertyExteriorSpaceTypes( $property );
            }
            if ( ! empty( getPropertyExteriorSpaceArea( $property )['value'] ) ) {
                $data[] = getPropertyExteriorSpaceArea( $property );
            }
            if ( ! empty( getPropertyExteriorSpaceGarden( $property )['value'] ) ) {
                $data[] = getPropertyExteriorSpaceGarden( $property );
            }

            if ( ! empty( $data ) ) {
                echo $this->render_property_table( $data, $name, $title );
            }
        }
        /**
         * Property Data Table - Storage space
         */
        public function property_data_details_storage_space( $data = array() ) {

            $data = array();
            $post_id = get_queried_object_id();
            $property = get_post( $post_id );
            if ( ! $property ) {
                return;
            }

            $title = __( 'Storage space', YSD_MAPI_TEXT_DOMAIN );
            $name  = 'storage_space';

            if ( ! empty( $data ) ) {
                echo $this->render_property_table( $data, $name, $title );
            }
        }

        /**
         * Property Data Table - Garage
         */
        public function property_data_details_garage( $data = array() ) {

            $data = array();
            $post_id = get_queried_object_id();
            $property = get_post( $post_id );
            if ( ! $property ) {
                return;
            }

            $title = __( 'Garage', YSD_MAPI_TEXT_DOMAIN );
            $name  = 'garage';

            if ( ! empty( getPropertyGarageType( $property )['value'] ) ) {
                $data[] = getPropertyGarageType( $property );
            }
            if ( ! empty( getPropertyGarageCapacity( $property )['value'] ) ) {
                $data[] = getPropertyGarageCapacity( $property );
            }
            if ( ! empty( getPropertyGarageArea( $property )['value'] ) ) {
                $data[] = getPropertyGarageArea( $property );
            }

            if ( ! empty( $data ) ) {
                echo $this->render_property_table( $data, $name, $title );
            }
        }

    }

}