<?php

/**
 * Business Plugin Helpers
 * Helpers: get_image_sizes, get_term_list, generate_css_class, build_link, generate_post_list
 */

class YSD_Mapi_Helpers {

	public static function get_image_sizes() {
		global $_wp_additional_image_sizes;

		$sizes  = array();
		$output = array();

		$get_sizes = get_intermediate_image_sizes();

		array_push( $get_sizes, 'full' );

		$get_sizes = array_combine( $get_sizes, $get_sizes );

		foreach ( $get_sizes as $_size ) {
			if ( in_array( $_size, array( 'full', 'thumbnail', 'medium', 'medium_large', 'large' ) ) ) {
				$sizes[ $_size ]['width']  = get_option( "{$_size}_size_w" );
				$sizes[ $_size ]['height'] = get_option( "{$_size}_size_h" );
				$sizes[ $_size ]['crop']   = (bool) get_option( "{$_size}_crop" );
			} elseif ( isset( $_wp_additional_image_sizes[ $_size ] ) ) {
				$sizes[ $_size ] = array(
					'width'  => $_wp_additional_image_sizes[ $_size ]['width'],
					'height' => $_wp_additional_image_sizes[ $_size ]['height'],
					'crop'   => $_wp_additional_image_sizes[ $_size ]['crop'],
				);
			}
		}

		foreach ( $sizes as $image_size => $image_size_data ) {
			$crop = $height = $width = '';

			$img_size_name = str_replace( '_', ' ', ucwords( $image_size ) );

			// If image size is not full
			if ( $image_size_data['height'] != false && $image_size_data['width'] != false ) {
				$height = $image_size_data['height'] === '0' ? 'auto' : $image_size_data['height'];
				$width  = $image_size_data['width'] === '0' ? 'auto' : $image_size_data['width'];

				$img_size_name .= ' (' . $width . ' x ' . $height . ')';
			}

			// Croop info
			//
			// if(is_array($image_size_data['crop'])){
			// $crop = 'true '.$image_size_data['crop'][0].'-'.$image_size_data['crop'][0];
			// }else{
			// $crop = $image_size_data['crop'] ? 'true auto' : 'false';
			// }
			$output[ $img_size_name ] = $image_size;
		}

		return $output;
	}

	public static function get_term_list( $taxonomy, $default = true ) {

		$list = $default ? array( '---' => false ) : array();

		$tax = $taxonomy ? $taxonomy : false;

		if ( ! $tax ) {
			return;
		}

		$terms = get_terms(
			array(
				'taxonomy'   => $tax,
				'hide_empty' => true,
			)
		);

		// Check if taxonomy is valid
		if ( is_wp_error( $terms ) ) {
			return array();
		} else {
			foreach ( $terms as $key => $value ) {
				$list[ $value->name ] = $value->term_id;
			}
		}

		return $list;
	}

	 /**
	  * Generate a string based on array values.
	  */
	public static function generate_css_class( $class = array(), $flush = false ) {
		$output = '';
		$space  = $flush ? '' : ' ';

		if ( empty( $class ) ) {
			return false;
		}

		// Check is we get an array
		if ( is_array( $class ) ) {
			$isFirst = 0;

			foreach ( $class as $css_class ) {
				++$isFirst;

				// if we have multiple values flush only the first space
				if ( 1 === $isFirst && $flush ) {
					$space = '';
				} else {
					$space = ' ';
				}

				// Check if we have a valid value and field is not empty
				if ( ! empty( $css_class ) ) {
					$output .= $space . $css_class;
				}
			}
		} else {
			// Check if we have a valid value and field is not empty
			if ( ! empty( $class ) ) {
				$output = $space . $class;
			}
		}

		return $output;
	}

	private static function parse_multi_attribute( $value, $default = array() ) {
		$result       = $default;
		$params_pairs = explode( '|', $value );
		if ( ! empty( $params_pairs ) ) {
			foreach ( $params_pairs as $pair ) {
				$param = preg_split( '/\:/', $pair );
				if ( ! empty( $param[0] ) && isset( $param[1] ) ) {
					$result[ $param[0] ] = rawurldecode( $param[1] );
				}
			}
		}

		return $result;
	}

	public static function build_link( $value ) {
		return self::parse_multi_attribute(
			$value,
			array(
				'url'    => '',
				'title'  => '',
				'target' => '',
				'rel'    => '',
			)
		);
	}

	public static function generate_post_list( $post_type, $array_invert = false, $add_empty = false ) {
		$p_type = $post_type ? $post_type : false;

		$list = array();

		if ( ! $p_type ) {
			return array( '' => '' ); // empty
		}

		$args = array(
			'post_type'      => $p_type,
			'posts_per_page' => -1,
			'orderby'        => 'title',
			'order'          => 'ASC',
		);

		$post_list = get_posts( $args );

		if ( $post_list ) {
			foreach ( $post_list as $post ) {
				setup_postdata( $post );
				$title = get_the_title( $post->ID );

				if ( $array_invert ) {
					if ( $add_empty ) {
						$list[0] = '---';
					}
					$list[ $post->post_title ] = $title;
				} else {
					if ( $add_empty ) {
						$list['---'] = 0;
					}
					$list[ $title ] = $post->post_title;
				}
			}
			wp_reset_postdata();
		}

		return $list;
	}


}