<?php

/********************
 * Archive Functions
*********************/

if ( ! function_exists( 'mapi_remove_content_spacing' ) ) {
    
    /*
     * Property Archive - Remove Spacings
     */
    function mapi_remove_content_spacing() {
        if ( is_archive( 'property' ) ) {
            remove_action('ysp_before_content', 'ysp_spacing_before_content');
            remove_action('ysp_after_content', 'ysp_spacing_after_content');
        }
    }
}

if ( ! function_exists( 'mapi_properties_before_wrapper_output' ) ) {
    
    /*
     * Property Archive - Before Wrapper
     */
    function mapi_properties_before_wrapper_output() {

        $output = $holder_class = $container_class = $row_class = '';

        // Holder Class
        $archive_holder_class = get_option( 'ysd-mapi_archive_holder_class' );
        $holder_class = !empty( $archive_holder_class ) && is_ysp_theme() ? ' '. $archive_holder_class : '';
        $holder = '<div class="mapi-property-archive'. $holder_class .'">';
        
        // Container Class
        $archive_template = get_option( 'ysd-mapi_archive_template', 'sidebar' );
        $container_class = ( 'full_width' === $archive_template ) ? 'c-no-container' : 'c-container';
        $container = '<div class="'. $container_class .'">';
        
        // Row Class
        $archive_row_class = get_option( 'ysd-mapi_archive_row_class', 'u-flex-row-reverse' );
        $row_class = ( 'full_width' !== $archive_template ) ? ' '. $archive_row_class : '';
        $row = '<div class="c-row'. $row_class .'">';
        
        $output .= (is_ysp_theme()) ? $holder . $container . $row : $holder;

        echo $output;
    }
}

if ( ! function_exists( 'mapi_properties_after_wrapper_output' ) ) {

    /*
     * Property Archive - After Wrapper
     */
    function mapi_properties_after_wrapper_output() {

        $close_row = $close_column = $close_holder = '';

                $close_row .= '</div>';
            $close_column .= '</div>';
        $close_holder .= '</div>';


        echo (is_ysp_theme()) ? $close_row . $close_column . $close_holder : $close_holder;
    }
}

if ( ! function_exists( 'mapi_properties_loop_header' ) ) {
    
    /**
     * Property loop start
     */
	function mapi_properties_loop_header() {

        $archive_header = get_option( 'ysd-mapi_archive_header', true);
        if (!$archive_header) return;

		if (shortcode_exists( 'property_archive_header' )) {
            echo do_shortcode( '[property_archive_header]' );
        }
	}
}

if ( ! function_exists( 'mapi_properties_loop_content' ) ) {
    
    /**
     * Property loop output
     */
	function mapi_properties_loop_content() {
		if (shortcode_exists( 'property_archive_loop' )) {
            echo do_shortcode( '[property_archive_loop]' );
        }
	}
}

if ( ! function_exists( 'mapi_properties_loop_footer' ) ) {
    
    /**
     * Property loop end
     */
	function mapi_properties_loop_footer() {

        $archive_footer = get_option( 'ysd-mapi_archive_footer', true);
        if (!$archive_footer) return;

		if (shortcode_exists( 'property_archive_footer' )) {
            echo do_shortcode( '[property_archive_footer]' );
        }
	}
}

if ( ! function_exists( 'mapi_no_properties_found_message' ) ) {
    
    /**
     * No properties found message
     */
	function mapi_no_properties_found_message() {
		_e( 'Sorry, nothing found.', YSD_MAPI_TEXT_DOMAIN );
	}
}

if ( ! function_exists( 'mapi_archive_main_start' ) ) {
    
    /**
     * Archive Main Start
     */
	function mapi_archive_main_start() {
        $class = '';
        $option = get_option( 'ysd-mapi_archive_main_columns' );
        $class = ( !empty( $option ) && is_ysp_theme() ) ? ' '. $option : '';
        ?>
        <div id="primary" class="mapi-content-area content-area<?php echo $class; ?>">
            <main id="main" class="mapi-main">
        <?php
	}
}

if ( ! function_exists( 'mapi_archive_main_end' ) ) {
    
    /**
     * Archive Main End
     */
	function mapi_archive_main_end() {
        ?>
            </main>
        </div>
        <?php
	}
}

if ( ! function_exists( 'mapi_archive_side_start' ) ) {
    
    /**
     * Archive Side Start
     */
	function mapi_archive_side_start() {
        $class = '';
        $option = get_option( 'ysd-mapi_archive_aside_columns' );
        $class = ( !empty( $option ) && is_ysp_theme() ) ? ' '. $option : '';
        
        $archive_template = get_option( 'ysd-mapi_archive_template', 'sidebar' );
        if ( $archive_template === 'sidebar' ) {
            ?>
            <aside id="secondary" class="mapi-sidebar-area sidebar-area<?php echo $class; ?>" role="complementary">
            <?php
        }
	}
}

if ( ! function_exists( 'mapi_archive_side_end' ) ) {
    
    /**
     * Archive Side End
     */
	function mapi_archive_side_end() {
        $archive_template = get_option( 'ysd-mapi_archive_template', 'sidebar' );
        if ( $archive_template === 'sidebar' ) {
            ?>
                </aside>
            <?php
        }
	}
}

if ( ! function_exists( 'mapi_archive_side_sidebar' ) ) {
    
    /**
     * Archive Side Sidebar
     */
	function mapi_archive_side_sidebar() {

        $archive_template = get_option( 'ysd-mapi_archive_template', 'sidebar' );
        $archive_widget_area = get_option( 'ysd-mapi_archive_sidebar_widget_area', true );

        if ( 'sidebar' === $archive_template && true == $archive_widget_area ) {
            if ( is_active_sidebar( 'mapi-archive-sidebar' ) ) {
                dynamic_sidebar( 'mapi-archive-sidebar' );
            }
        }
	}
}

if ( ! function_exists( 'mapi_archive_side_search' ) ) {
    
    /**
     * Archive Side Search
     */
	function mapi_archive_side_search() {

        $archive_template = get_option( 'ysd-mapi_archive_template', 'sidebar' );
        $archive_filter = get_option( 'ysd-mapi_archive_filter', true );

        if ( 'sidebar' === $archive_template && true == $archive_filter ) {
            if (shortcode_exists( 'property_archive_search' )) {
                echo do_shortcode( '[property_archive_search]' );
            }
        }
	}
}

if ( ! function_exists( 'mapi_archive_map_layout' ) ) {
    
    /**
     * Archive Map Layout
     */
	function mapi_archive_map_layout() {

        $archive_filter = get_option( 'ysd-mapi_archive_map', true );

        if ( true == $archive_filter ) {
            if (shortcode_exists( 'property_archive_map' )) {
                echo do_shortcode( '[property_archive_map]' );
            }
        }
	}
}

if ( ! function_exists( 'mapi_archive_pre_get_posts' ) ) {
    
    /**
     * Archive pre_get_posts
     */
    function mapi_archive_pre_get_posts($query) {

        if ( is_archive('property') && !is_admin() && $query->is_main_query() ) {

            $get_ppp = (isset($_GET['posts_per_page'])) ? $_GET['posts_per_page'] : '';
            $ppp = mapi_posts_per_page( $get_ppp, true );
            
            $query->set('posts_per_page', $ppp);
        }

    }
}

if ( ! function_exists( 'mapi_get_properties_per_row' ) ) {

    /**
     * Archive Properties per row
     */
    function mapi_get_properties_per_row() {

        $output = '';
        $option = get_option( 'ysd-mapi_archive_properties_per_row', 2 );
        
        $output = 'c-properties--columns-' . $option;
        return $output;
    }
}