<?php

if ( ! function_exists( 'mapi_non_ysp_theme' ) ) {

    /*
     * Add Body Class
     */
    function mapi_non_ysp_theme( $classes ) {
        
        if (!is_ysp_theme()) {
            $classes[] = 'is-no-ysp-theme';
        }
        
        return $classes;
        
    }
    add_filter( 'body_class', 'mapi_non_ysp_theme' );
}

if ( ! function_exists( 'mapi_posts_per_page' ) ) {

    /*
     * Get the right post_per_page data
     */
    function mapi_posts_per_page( $value = '', $single_result = true ) {

        $output = '';

        $options = get_option( 'ysd-mapi_archive_per_page_options', '10,20,40,80' );
        $options = !empty($options) ? $options : '10,20,40,80'; // Fallback
        $options = explode(',', $options);

        $multi = [];
        if ( !empty($options) ) {

            if ( true == $single_result ) {
                $single = intval($options[0]);
            } else {
                foreach ($options as $option) {
                    $multi[] = intval($option);
                }
            }

        }
        
        $output = !empty($single) ? $single : $multi;
        $output = !empty($value) ? $value : $output;

        $output = !empty($output) ? $output : '';

        return $output;
    }
}

/**
 * Get templates and include the file.
 *
 * @param string $template_name Template name.
 * @param array  $args          Arguments. (default: array).
 * @param string $template_path Template path. (default: '').
 * @param string $default_path  Default path. (default: '').
 */

if ( ! function_exists('mapi_get_template') ) {
    function mapi_get_template( $template_name, $args = array(), $template_path = '', $default_path = '' ) {
        $cache_key = sanitize_key( implode( '-', array( 'template', $template_name, $template_path, $default_path, YSD_MAPI_VERSION ) ) );
        $template  = (string) wp_cache_get( $cache_key, 'mapi' );

        if ( ! $template ) {
            $template = mapi_locate_template( $template_name, $template_path, $default_path );
        } else {
            $template = '';
        }

        // Allow 3rd party plugin filter template file from their plugin.
        $filter_template = apply_filters( 'mapi_get_template', $template, $template_name, $args, $template_path, $default_path );

        if ( $filter_template !== $template ) {
            if ( ! file_exists( $filter_template ) ) {
                /* translators: %s template */
                return sprintf( __( '%s does not exist.', YSD_MAPI_TEXT_DOMAIN ), '<code>' . $filter_template . '</code>' );
            }
            $template = $filter_template;
        }
        
        include $template;
    }
}

/**
 * Locate a template and return the path for inclusion.
 *
 * This is the load order:
 *
 * yourtheme/$template_path/$template_name
 * yourtheme/$template_name
 * $default_path/$template_name
 *
 * @param string $template_name Template name.
 * @param string $template_path Template path. (default: '').
 * @param string $default_path  Default path. (default: '').
 * @return string
 */

if ( ! function_exists('mapi_locate_template') ) {
    function mapi_locate_template( $template_name, $template_path = '', $default_path = '' ) {
        if ( ! $template_path ) {
            $template_path = 'mapi/';
        }

        if ( ! $default_path ) {
            $default_path = YSD_MAPI_PARTIALS_PATH . '/';
        }
        
        // Look within passed path within the theme - this is priority.
        $template = locate_template(
            array(
                trailingslashit( $template_path ) . $template_name,
                $template_name,
            )
        );

        // Get default template/.
        if ( ! $template ) {
            $template = $default_path . $template_name;
        }

        // Return what we found.
        return apply_filters( 'mapi_locate_template', $template, $template_name, $template_path );
    }
}

/**
 * Get an item from an array using "dot" notation.
 *
 * @param  array   $array
 * @param  string  $key
 * @param  mixed   $default
 * @return mixed
 */
if ( ! function_exists('mapi_get_property_layout')) {
	function mapi_get_property_layout($array, $key, $set_default = null) {
        $default = get_option( 'ysd-mapi_archive_properties_layout', 'grid' );

		if (is_null($key)) return $array;

		if (isset($array[$key])) return $array[$key];

		foreach (explode('.', $key) as $segment) {
			if ( ! is_array($array) || ! array_key_exists($segment, $array)) {
				if ( ! empty( $set_default ) ) {
                    return $set_default;
                } else {
                    return $default;
                }
			}

			$array = $array[$segment];
		}

		return $array;
	}
}

/**
 * Property Filters
 */
if ( ! function_exists('get_mapi_property_filters') ) {
	function get_mapi_property_filters( $filter_class = "mapi-filter__item" ) {
        //Get all posts for autofill
        $args = array(
            'post_type' => 'property',
            'posts_per_page' => -1
        );
        $query = new WP_Query($args);
        $posts = $query->get_posts();

        $mapiPF = '';
        if ( class_exists( 'Mapi_Property_Filters' ) ) {
            $current_language = apply_filters( 'wpml_current_language', NULL );
            $current_language = ($current_language) ? strtoupper( $current_language ) : 'NL';
            $mapiPF = new Mapi_Property_Filters();
            $mapiPF = $mapiPF->get_filter( $current_language );
        }

        if ( !empty( $mapiPF ) ) {
            foreach ( $mapiPF as $filter_id => $filter_args ) {
                /* Autofill filter based on meta value from existing posts */
                if(isset($filter_args['autofill']) && isset($filter_args['meta']) && $filter_args['autofill'])
                {
                    $options = [];
                    foreach($posts as $post)
                    {
                        $meta_value = get_post_meta($post->ID, $filter_args['meta'], true);

                        if(!in_array($meta_value, $options))
                        {
                            $options[$meta_value] = $meta_value;
                        }
                    }

                    $filter_args['options'] = array_merge($filter_args['options'] ?? [], $options);
                }

                $filters[] = new \ysdmapi\includes\custom_fields\CustomField($filter_id, $filter_args['label'], $filter_args['type'], null, $_GET[$filter_id] ?? $filter_args['value'] ?? null, $filter_args['options'] ?? null, $filter_args['emptyLabelMin'] ?? null, $filter_args['emptyLabelMax'] ?? null, $filter_args['optionsMin'] ?? null, $filter_args['optionsMax'] ?? null);
            }
        }
        if ( !empty( $filters ) ) {
            $filter_class = $filter_class ? ' class="'. $filter_class .'"' : '';

            foreach ( $filters as $filter ) {
                echo '<div'. $filter_class .'>';
                    echo $filter->display();
                echo '</div>';
            }
        }

	}
}