<?php

/**
 * The public file of MAPI.
 *
 * This file is used to setup templates and their components, functions and hooks.
 *
 * @since      1.0.0
 *
 * @package    ysd-mapi
 * @subpackage ysd-mapi/front/partials
 */


/**
 * Property Media Sizes
 */
add_image_size( 'mapi_masonry_medium', 400, 275, array( 'center', 'center' ) );
add_image_size( 'mapi_masonry_large', 800, 550, array( 'center', 'center' ) );
add_image_size( 'mapi_medium', 300, 300, array( 'center', 'center' ) );


/**
 * Property Slider
 */
add_action ('wp_enqueue_scripts', 'mapi_add_slider_script'); // Slider - JS
function mapi_add_slider_script() {

    /* Swiper Script */
    if ( ! wp_script_is( 'swiper_core', 'registered' ) ) {
        wp_register_script( 'swiper_core', 'https://cdnjs.cloudflare.com/ajax/libs/Swiper/5.4.1/js/swiper.min.js', array( 'jquery' ), '5.4.1', true );
    }

    /* Swiper Style */
    if ( ! wp_script_is( 'swiper_style_core', 'registered' ) ) {
        wp_register_style( 'swiper_style_core', 'https://cdnjs.cloudflare.com/ajax/libs/Swiper/5.4.1/css/swiper.min.css', array(), '5.4.1' );
    }
    
    // Register Property Slider Script
    wp_register_script( 'property-slider', YSD_MAPI_PLUGIN_URL . 'front/assets/src/js/shortcodes/property-slider.js', array( 'swiper_core' ), YSD_MAPI_VERSION, true );

}

/**
 * Property Print/Share/Like
 */
add_action ('wp_enqueue_scripts', 'mapi_add_icons_script'); // Print/Share/Like - JS
function mapi_add_icons_script() {   

    // Register Property Print/Share/Like Script
    wp_register_script( 'property-icons', YSD_MAPI_PLUGIN_URL . 'front/assets/src/js/components/property-icons.js' , array( 'jquery' ), YSD_MAPI_VERSION, true );
    wp_enqueue_script('property-icons');
    $params = array(
        'url' => content_url()
    );
    wp_localize_script('property-icons', 'urlpath', $params);

}


/**
 * Property Fancybox
 */

// Fancybox - JS
add_action ('wp_enqueue_scripts', 'mapi_add_fancybox_script');
function mapi_add_fancybox_script() {
    if ( class_exists( 'fancybox' ) ) return;

    if ( 'enabled' != get_option( 'ysd-mapi_load_fancybox' ) ) {
        return;
    }
    
    // Register Script
    wp_register_script( 'mapi-fancybox-script', 'https://cdnjs.cloudflare.com/ajax/libs/fancybox/3.5.7/jquery.fancybox.min.js', array('jquery'), '3.5.7', true );
    
    // Enqueue Script on Property Single
    if ( is_singular( 'property' ) ) {
        wp_enqueue_script('mapi-fancybox-script');
    }
}

// Fancybox - CSS
add_action( 'wp_enqueue_scripts', 'mapi_add_fancybox_style' );
function mapi_add_fancybox_style() {
    if ( class_exists( 'fancybox' ) ) return;

    if ( 'enabled' != get_option( 'ysd-mapi_load_fancybox' ) ) {
        return;
    }
    
    /* Fancybox */
    wp_register_style( 'mapi-fancybox-style', 'https://cdnjs.cloudflare.com/ajax/libs/fancybox/3.5.7/jquery.fancybox.min.css', array(), '3.5.7' ); 
    
    // Enqueue Script on Property Single
    if ( is_singular( 'property' ) ) {
        wp_enqueue_style('mapi-fancybox-style');
    }
}


/**
 * Plugin Helpers
 */
require YSD_MAPI_PARTIALS_PATH . '/includes/plugin-helpers.php';


/**
 * Mapi Property Template
 */
require YSD_MAPI_PARTIALS_PATH . '/shortcodes/templates/class-property-template.php';


/**
 * Property Shortcodes
 */

// Components - Shortcodes
require YSD_MAPI_PARTIALS_PATH . '/components/shortcodes/property-featured-shortcode.php';
require YSD_MAPI_PARTIALS_PATH . '/components/shortcodes/property-map-shortcode.php';
require YSD_MAPI_PARTIALS_PATH . '/components/shortcodes/property-related-shortcode.php';
require YSD_MAPI_PARTIALS_PATH . '/components/shortcodes/property-shortcode.php';

// Components - Visual Composer
if ( defined( 'WPB_VC_VERSION' ) ) { // Only load when WP Bakery is activated
    require YSD_MAPI_PARTIALS_PATH . '/components/visual-composer/property-featured-to-vc.php';
    require YSD_MAPI_PARTIALS_PATH . '/components/visual-composer/property-map-to-vc.php';
    require YSD_MAPI_PARTIALS_PATH . '/components/visual-composer/property-related-to-vc.php';
    require YSD_MAPI_PARTIALS_PATH . '/components/visual-composer/property-to-vc.php';
}

// Template Components
require YSD_MAPI_PARTIALS_PATH . '/template-components/single/property-contact-shortcode.php';
require YSD_MAPI_PARTIALS_PATH . '/template-components/single/property-data-shortcode.php';
require YSD_MAPI_PARTIALS_PATH . '/template-components/single/property-description-shortcode.php';
require YSD_MAPI_PARTIALS_PATH . '/template-components/single/property-footer-shortcode.php';
require YSD_MAPI_PARTIALS_PATH . '/template-components/single/property-gallery-shortcode.php';
require YSD_MAPI_PARTIALS_PATH . '/template-components/single/property-gallery-compact-shortcode.php';
require YSD_MAPI_PARTIALS_PATH . '/template-components/single/property-header-shortcode.php';
require YSD_MAPI_PARTIALS_PATH . '/template-components/single/property-map-shortcode.php';
require YSD_MAPI_PARTIALS_PATH . '/template-components/single/property-status-shortcode.php';
require YSD_MAPI_PARTIALS_PATH . '/template-components/single/property-next-page-shortcode.php';
require YSD_MAPI_PARTIALS_PATH . '/template-components/single/property-prev-page-shortcode.php';
require YSD_MAPI_PARTIALS_PATH . '/template-components/single/property-agency-shortcode.php';


// Template Parts
require YSD_MAPI_PARTIALS_PATH . '/template-parts/property-archive-footer-shortcode.php';
require YSD_MAPI_PARTIALS_PATH . '/template-parts/property-archive-header-shortcode.php';
require YSD_MAPI_PARTIALS_PATH . '/template-parts/property-archive-loop-shortcode.php';
require YSD_MAPI_PARTIALS_PATH . '/template-parts/property-archive-search-shortcode.php';
require YSD_MAPI_PARTIALS_PATH . '/template-parts/property-archive-map-shortcode.php';

// More Shortcodes
require YSD_MAPI_PARTIALS_PATH . '/shortcodes/class-property-shortcodes.php';
require YSD_MAPI_PARTIALS_PATH . '/shortcodes/property-shortcodes.php';

/**
 * Property Components Archive
 */
require YSD_MAPI_PARTIALS_PATH . '/template-components/archive/property-filter-result-count.php';
require YSD_MAPI_PARTIALS_PATH . '/template-components/archive/property-filter-toggle.php';
require YSD_MAPI_PARTIALS_PATH . '/template-components/archive/property-filter-values.php';
require YSD_MAPI_PARTIALS_PATH . '/template-components/archive/property-layout-toggle.php';
require YSD_MAPI_PARTIALS_PATH . '/template-components/archive/property-orderby.php';
require YSD_MAPI_PARTIALS_PATH . '/template-components/archive/property-pagination.php';
require YSD_MAPI_PARTIALS_PATH . '/template-components/archive/property-posts-per-page.php';
require YSD_MAPI_PARTIALS_PATH . '/template-components/archive/property-query.php';


/**
 * Property Data
 */
require YSD_MAPI_PARTIALS_PATH . '/data-tables/address-details.php';
require YSD_MAPI_PARTIALS_PATH . '/data-tables/transfer.php';
require YSD_MAPI_PARTIALS_PATH . '/data-tables/construction.php';
require YSD_MAPI_PARTIALS_PATH . '/data-tables/surface.php';
require YSD_MAPI_PARTIALS_PATH . '/data-tables/layout.php';
require YSD_MAPI_PARTIALS_PATH . '/data-tables/energy.php';
require YSD_MAPI_PARTIALS_PATH . '/data-tables/exterior-space.php';
require YSD_MAPI_PARTIALS_PATH . '/data-tables/garage.php';


/**
 * Property Includes Data
 */
require YSD_MAPI_PARTIALS_PATH . '/includes/data/property-filters.php';
require YSD_MAPI_PARTIALS_PATH . '/includes/data/property-formatter.php';
require YSD_MAPI_PARTIALS_PATH . '/includes/data/property-tables.php';
require YSD_MAPI_PARTIALS_PATH . '/includes/data/property-js-data.php';


/**
 * Property Template Includes
 */
require YSD_MAPI_PARTIALS_PATH . '/includes/template/mapi-template-functions-archive.php';
require YSD_MAPI_PARTIALS_PATH . '/includes/template/mapi-template-functions-single.php';
require YSD_MAPI_PARTIALS_PATH . '/includes/template/mapi-template-helpers.php';
require YSD_MAPI_PARTIALS_PATH . '/includes/template/mapi-template-hooks.php';

/**
 * Property Includes Widgets
 */
require YSD_MAPI_PARTIALS_PATH . '/includes/widgets.php';