<?php

if ( ! class_exists( 'Mapi_Property_Gallery' ) ) {

    /*
     * Mapi Property Shortcodes
     */
    class Mapi_Property_Shortcodes {

        public function __construct() {
            add_shortcode( 'mapi_field', array( $this, 'mapi_field_shortcode' ) );
            add_shortcode( 'mapi_function', array( $this, 'mapi_function_shortcode' ) );
            add_shortcode( 'mapi_price', array( $this, 'mapi_price_shortcode' ) );
            add_shortcode( 'mapi_amount', array( $this, 'mapi_amount_shortcode' ) );
            add_shortcode( 'mapi_employee', array( $this, 'mapi_employee_shortcode' ) );
        }

        /*
         * Mapi Field Shortcode
         */
        public function mapi_field_shortcode($atts) {
            $atts = shortcode_atts(
                array(
                    'field'         => '',
                    'type'          => 'text',
                    'class'         => '',
                    'prefix'        => '',
                    'suffix'        => '',
                    'icon'          => '',
                ),
                $atts
            );

            $output = '';
            $id = get_queried_object_id();
            $property = get_post( $id );
            $field = get_post_meta($id, $atts['field'], true);
            $getPrice = getFormattedLocalePrice($property);

            if ( empty( $atts['type'] ) ) {
                return;
            }

            if(!empty($atts['field'])){
                if($atts['field'] == 'price'){
                    $field = $getPrice;
                }
            }

            if(!empty($atts['prefix'])){
                $prefix = ' ' . $atts['prefix'] . ' ';
            } else{
                $prefix = '';
            }

            $volume_square = getRealtorVolumeUnits( 'square' );
            $volume_cubic = getRealtorVolumeUnits( 'cubic' );
            $sale_condition = getPropertySaleCondition( $property );

            if(!empty($atts['suffix']) && $atts['suffix'] != 'empty'){
                $suffix = ' ' . $atts['suffix'] . ' ';
            }elseif($atts['suffix'] == 'empty'){
                $suffix = '';
            }else{
                if($atts['field'] == 'usable_area' || $atts['field'] == 'plot_area'){
                    $suffix = $volume_square;
                }
                
                if($atts['field'] == 'volume_area'){
                    $suffix = $volume_cubic;
                }

                if($atts['field'] == 'price'){
                    $suffix = $sale_condition;
                }
            }

            if(!empty($atts['icon'])){
                $icon = '<i class="' . $atts['icon'].'"></i>';
            } else{
                $icon = '';
            }

            if(!empty($field)){
                $output .= '<span class="' . $atts['class'] . '">' . $icon . '<span class="prefix">' . $prefix . '</span>' . '<span class="mapi-field">' . $field . '</span' . '<span class="suffix">' . $suffix . '</span></span>';
            }else{
                $output .= '<span class="' . $atts['class'] . '"></span>';
            }
            
            return $output;
        }


        /*
         * Mapi Function Shortcode
         */
        public function mapi_function_shortcode($atts) {
            $options = shortcode_atts(
                array(
                    'id'        =>  '',
                    'name'      =>  '',
                    'output'    =>  '',
                ),
                $atts
            );
            
            if ( empty( $options['name'] ) ) {
                return;
            }
            
            $output = $fn = '';

            $id = !empty( $options['id'] ) ? $options['id'] : get_the_id();
            $property = get_post( $id );
            $na = __( 'N/A', YSD_MAPI_TEXT_DOMAIN );

            if ( function_exists( $options['name'] ) ) {
                $fn     = call_user_func( $options['name'], $property );
                if ( !empty($options['output']) ) {
                    $output = !empty($fn[$options['output']]) ? $fn[$options['output']] : $na;
                }
            } else {
                $output = $na;
            }

            return $output;
        }


        /*
         * Property Price Shortcode
         */
        public function mapi_price_shortcode($atts) {
            $atts = shortcode_atts(
                array(
                    'id' => '',
                    'tag' => 'div',
                    'hide_label' => false,
                    'hide_value' => false,
                    'hide_value_label' => false,
                ),
                $atts
            );

            $output = '';

            $id = ! empty( $atts['id'] ) ? $atts['id'] : get_queried_object_id();
            $property = get_post( $id );
            $propertyPrice = getPropertyPrice( $property );

            if ( $atts['hide_label'] ) {
                unset( $propertyPrice['label'] );
            }
            if ( $atts['hide_value'] ) {
                unset( $propertyPrice['value'] );
            }
            if ( $atts['hide_value_label'] ) {
                unset( $propertyPrice['value_label'] );
            }
            
            if ( ! empty( $propertyPrice ) ) {
                $output = implode(" ", $propertyPrice);
            }

            return '<'. $atts['tag'] .' class="c-property-price">'. $output .'</'. $atts['tag'] .'>';
        }


        /*
         * Property Amount Shortcode
         */
        public function mapi_amount_shortcode($atts) {
            $options = shortcode_atts(
                array(
                    'tag'   => 'div',
                    'type'  => '',
                    'prefix' => '',
                    'suffix' => '',
                ),
                $atts
            );

            $output = '';

            $args = array(
                'post_type'      => 'property',
                'posts_per_page' => -1,
            );

            if ( !empty( $options['type'] ) ) {
                $args['meta_query'] = array(
                    array(
                        'key' => 'sale_type',
                        'value' => $options['type'],
                    )
                );
            }

            $properties = get_posts( $args );
            $amount = !empty($properties) ? count($properties) : '';

            $prefix  = $options['prefix'] ? ' '. $options['prefix'] : '';
            $suffix  = $options['suffix'] ? $options['suffix'] .' ' : '';
            $output = !empty($amount) ? $suffix . $amount . $prefix : 0;

            return '<'. $options['tag'] .' class="c-property-amount">'. $output .'</'. $options['tag'] .'>';
        }


        /*
         * Property Employee Shortcode
         */
        public function mapi_employee_shortcode($atts) {
            $options = shortcode_atts(
                array(
                    'id' => '',
                    'tag' => 'div',
                    'hide_title' => false,
                    'hide_position' => false,
                    'hide_phone' => false,
                    'hide_email' => false,
                ),
                $atts
            );

            $output = '';

            $id = ! empty( $options['id'] ) ? $options['id'] : get_queried_object_id();
            $accountmanager = get_post_meta($id, 'accountmanager', true);

            $args = array(
                'post_type' => 'employee',
                'posts_per_page' => -1,
                'meta_query' => array(
                    array(
                        'key' => 'accountmanager',
                        'value' => $accountmanager,
                        'compare' => '=',
                    ),
                    array(
                        'key' => 'accountmanager',
                        'value' => '',
                        'compare' => '!=',
                    ),
                ),
            );
            $query = new WP_Query($args);

            $employees = $query->get_posts();
            if ( isset( $employees[0] ) ) {
                $employee = $employees[0];

                $title = $employee->post_title;
                $posit = get_post_meta( $employee->ID, '_employee_position', true );
                $phone = get_post_meta( $employee->ID, '_employee_phone_number', true );
                $email = get_post_meta( $employee->ID, '_employee_email_address', true );

                $title = !empty( $title ) && false == $options['hide_title'] ? $title : '';
                $posit = !empty( $posit ) && false == $options['hide_position'] ? $posit : '';
                $phone = !empty( $phone ) && false == $options['hide_phone'] ? $phone : '';
                $email = !empty( $email ) && false == $options['hide_email'] ? $email : '';

                if ( ! empty( $title ) ) {
                    $output .= '<div class="property-contact-name">'. $title .'</div>';
                }
                if ( ! empty( $posit ) ) {
                    $output .= '<div class="property-contact-position">'. $posit .'</div>';
                }
                if ( ! empty( $phone ) ) {
                    $output .= '<a class="property-contact-phone" href="tel:'. $phone .'">'. $phone .'</a>';
                }
                if ( ! empty( $email ) ) {
                    $output .= '<a class="property-contact-email" href="mailto:'. $email .'">'. $email .'</a>';
                }

            }

            return '<'. $options['tag'] .' class="c-property-accountmanager">'. $output .'</'. $options['tag'] .'>';
        }

    }
    
}
new Mapi_Property_Shortcodes();