<?php
/***************************************
  Template - Property
****************************************/

class Mapi_Property_Template {

	private $settings = array(
		'post_id'       =>  null,
		'class'         =>  '',
		'link_single'   =>  true,
        'image'         =>  true,
		'img_size'      =>  'post-thumbnail',
        'new_label'     =>  true,
        'address'       =>  true,
        'city'          =>  true,
        'metadata'      =>  true,
        'price'         =>  true,
        'button'        =>  true,
        'button_text'   =>  '',
	);

	public function setArgs( $args ) {

		if ( ! empty( $args ) ) {
			foreach ( $args as $key => $value ) {
				$this->settings[ $key ] = $value;
			}
		}

	}

	public function render() {

		if ( ! isset( $this->settings['post_id'] ) ) {
			return '';
		}

		/**
		 * Setup initial options
		 */
		$post_id  = $this->settings['post_id'];
		$settings = $this->settings;

		/**
		 * Setup Property data
		 */
		$property = $this->get_post_type_data( $post_id, $settings['img_size'] );

		/**
		 * Setup template elements content
		 */
        $objectProperty = get_post( $post_id );

        // Class
        $class = $settings['class'] ? ' '. $settings['class'] : '';

        // Status
        $reset_tz = date_default_timezone_get();
        date_default_timezone_set('Europe/Amsterdam');
        $date_compare = date("Y-m-d H:i:s", strtotime("NOW -24 HOURS"));
        date_default_timezone_set($reset_tz);

        $is_new = false;
        $label = $property['status'] ? '<div class="c-property__status">'. $property['status'] .'</div>' : '';
        if ( ( $property['date'] >= $date_compare ) && ( $objectProperty->sale_status == 1 || $objectProperty->sale_status == 2 ) ) {
            $is_new = true;
            $label = '<div class="c-property__status c-property__status-new"><span class="c-sale-status c-sale-status--1">'. __( 'New', YSD_MAPI_TEXT_DOMAIN ) .'</span></div>';
        }

        // Link
		$link_start = $settings['link_single'] ? '<a class="c-property__link" href="' . get_the_permalink( $post_id ) . '">' : '';
		$link_end   = $settings['link_single'] ? '</a>' : '';
        
        // Image
        $image_fallback = YSD_MAPI_PLUGIN_URL . 'front/assets/src/images/image-placeholder.jpg';
        $image_url = $property['image'] ? $property['image'] : $image_fallback;
        $image = '<div class="c-property__image" style="background-image:url('. $image_url .');"></div>';
		$image = $image ? $link_start . $image . $link_end : '';

        // General
        $address = $property['address'] ? '<div class="c-property__address">'. $property['address'] .'</div>' : '';
        $city = $property['city'] ? '<div class="c-property__city">'. $property['city'] .'</div>' : '';

        // Price
        $price = $property['price'] ? '<div class="c-property__price">'. $property['price'] .'</div>' : '';

        // Button
        $button_start = '<div class="c-property__button-wrapper">';
        $button_end = '</div>';
        $button_label = $settings['button_text'] ? $settings['button_text'] : __( 'View details', YSD_MAPI_TEXT_DOMAIN );
        $button_link = '<a class="c-property__button" href="'. get_the_permalink( $post_id ) .'" rel="bookmark">'. $button_label .'</a>';
        $button = $settings['button'] ? $button_start . $button_link . $button_end : '';

        // Not Available
        $data_na = __( 'N/A', YSD_MAPI_TEXT_DOMAIN );

        /**
         * Setup template data
         */
        $data = array(
            'class' => $class,
            'is_new' => $is_new,
            'label' => $label,
            'image' => $image,
            'address' => $address,
            'city' => $city,
            'price' => $price,
            'button' => $button
        );
	
        // KIND of house
        $kind_lang = __( 'Kind of house', 'ysd-mapi' );
        $kind_data = shortcode_exists( 'mapi_function' ) ? do_shortcode( "[mapi_function name='getPropertyType' output='value']" ) : '';
        $kind_dtdd = $kind_data ? '<dt>'. $kind_lang .'</dt><dd>'. $kind_data .'</dd>' : '<dt>'. $kind_lang .'</dt><dd>'. $data_na .'</dd>';

        // LIVing Area
        $liva_lang = __( 'Living area', 'ysd-mapi' );
        $liva_data = shortcode_exists( 'mapi_function' ) ? do_shortcode( "[mapi_function name='getPropertyUsableArea' output='value']" ) : '';
        $liva_dtdd = $liva_data ? '<dt>'. $liva_lang .'</dt><dd>'. $liva_data .'</dd>' : '<dt>'. $liva_lang .'</dt><dd>'. $data_na .'</dd>';

        // NUMber of Rooms
        $numr_lang = __( 'Number of rooms', 'ysd-mapi' );
        $numr_data = shortcode_exists( 'mapi_function' ) ? do_shortcode( "[mapi_function name='getPropertyRooms' output='value']" ) : '';
        $numr_dtdd = $numr_data ? '<dt>'. $numr_lang .'</dt><dd>'. $numr_data .'</dd>' : '<dt>'. $numr_lang .'</dt><dd>'. $data_na .'</dd>';

        // NUMber of Bedrooms
        $numb_lang = __( 'Number of bedrooms', 'ysd-mapi' );
        $numb_data = shortcode_exists( 'mapi_function' ) ? do_shortcode( "[mapi_function name='getPropertyBedrooms' output='value']" ) : '';
        $numb_dtdd = $numb_data ? '<dt>'. $numb_lang .'</dt><dd>'. $numb_data .'</dd>' : '<dt>'. $numb_lang .'</dt><dd>'. $data_na .'</dd>';

		/**
		 * Setup template
		 */
		$default = sprintf(
			'<article class="c-property%s">
                <div class="c-property__header">%s%s</div>
                <div class="c-property__content">
                    <h3 class="c-property__title">%s%s</h3>
                    <div class="c-property__data-table">
                        <dl>%s%s%s%s</dl>
                    </div>
                    <div class="c-property__footer">%s%s</div>
                </div>
            </article>',
			$data['class'],
            $data['label'],
			$data['image'],
            $data['address'],
            $data['city'],
            $kind_dtdd,
            $liva_dtdd,
            $numr_dtdd,
            $numb_dtdd,
            $data['price'],
            $data['button']
		);

		$output = apply_filters( 'mapi_properties_loop_item', $default, $data );

		return $output;
	}

	private function get_post_type_data( $post_id = null, $size = 'post-thumbnail' ) {
		
        // Get Post
        $property = get_post( $post_id );
        
        // Date Created At
        $date = date("Y-m-d H:i:s", strtotime($property->created_at));

        // Status
        $status = function_exists('getPropertySaleStatus') ? getPropertySaleStatus( $property )['value'] : '';
        
        // Image
		$image = has_post_thumbnail( $post_id ) ? get_the_post_thumbnail_url( $post_id, $size ) : '';

        // Address / City / Price
        $address = getPropertyAddress( $property );
        $city    = $property->city;
        $price   = getPropertyPrice( $property );
        $price   = $price ? $price['value'] .' '. $price['value_label'] : '';

        $address = $address ? $address : '';
        $city    = $city ? $city : '';
        $price   = $price ? $price : '';

        // Output Data
		$output = array(
            'date'          =>  $date,
            'status'        =>  $status,
            'image'         =>  $image,
            'address'       =>  $address,
            'city'          =>  $city,
            'price'         =>  $price,
		);

        // Output
		return $output;
	}

}