<?php

if ( ! class_exists( 'Mapi_Property_Query' ) ) {

    class Mapi_Property_Query {
        
        /*
         * Property Query
         */
        public static function init() {

            $output = '';

            // Settings
            $posts_per_page = get_option( 'ysd-mapi_archive_properties_per_page', 10 );
            $ordering = get_option( 'ysd-mapi_archive_properties_ordering', 'date:desc' );
            $ordering = ! empty( $ordering ) ? explode(":", $ordering, 2) : 'date:desc';
            $orderby = ! empty( $ordering ) ? $ordering[0] : 'date';
            $order = ! empty( $ordering ) ? $ordering[1] : 'desc';
            
            // Paged
            $paged = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1;

            // Filter Query
            $filter_query = array(
                'post_type' => 'property',
                'post_status' => 'publish',
                'posts_per_page' => $posts_per_page,
                'orderby' => $orderby,
                'order' => $order,
                'paged' => $paged,
            );

            // Sale Status Ordering
            if ( 'sale_status' == $orderby ) {
                $filter_query['meta_key'] = 'sale_status';
                $filter_query['orderby'] = 'meta_value_num';
            }

            /**
             * Set Query Vars
             */
            $filter_query = self::set_query_vars( $filter_query );

            /**
             * Custom Queries
             */
            $filter_query = self::do_custom_queries( $filter_query );

            /**
             * Default Queries
             */
            $filter_query = self::do_default_queries( $filter_query );

            /**
             * Pretty Permalinks
             */
            $filter_query = self::do_pretty_permalinks( $filter_query );

            /**
             * WP_Query
             */
            $output = new WP_Query( $filter_query );

            // echo '<pre>';
            // var_dump($output);
            // echo '</pre>';
            // die();
            
            /**
             * Return Query
             */

            // Query: Meta
            $mapiPF = '';
            if ( class_exists( 'Mapi_Property_Filters' ) ) {
                $current_language = apply_filters( 'wpml_current_language', NULL );
                $current_language = ($current_language) ? strtoupper( $current_language ) : '';
                $mapiPF = new Mapi_Property_Filters();
                $mapiPF = $mapiPF->get_filter( $current_language );
            }

            // When '$_GET' not empty
            if ( ! empty( $_GET ) ) {
                
                // Create meta array
                $filter_meta = array();

                // Create loop of all meta from '$_GET'
                foreach ( $_GET as $key => $value ) {
                    
                    // Only if '$key' isset and '$value' not empty
                    if ( isset( $mapiPF[$key] ) && ! empty( $value ) && 'search' != $key ) {
                        $filter = $mapiPF[$key];

                        // Create variable with all meta
                        if ( ! is_array( $value ) ) {
                            
                            $filter_meta[$filter['meta']] = array(
                                'key' => $filter['meta'],
                                'value' => $value,
                                'compare' => $filter['compare'],
                                'type' => $filter['meta_type'] ?? null,
                            );

                            // Query: Sale Status
                            if ( !empty($_GET['sale_status']) ) {
                                $value = explode(',', $_GET['sale_status']);
                                $filter_meta['sale_status'] = array(
                                    'key' => 'sale_status',
                                    'value' => $value,
                                    'compare' => 'IN',
                                );
                            }

                            // Query: Object Type
                            if ( !empty($_GET['og']) ) {
                                $value = explode(',', $_GET['og']);
                                $filter_meta['og'] = array(
                                    'key' => 'og',
                                    'value' => $value,
                                    'compare' => 'IN',
                                );
                            }

                        } else if ( is_array( $value ) ) {

                            // Minimum
                            if ( ! empty( $_GET[$filter['meta']]['min'] ) ) {
                                $filter_meta[$filter['meta']][] = array(
                                    array(
                                        'key'       => $filter['meta'],
                                        'value'     => $_GET[$filter['meta']]['min'],
                                        'compare'   => '>=',
                                        'type'      => 'NUMERIC',
                                    ),
                                );
                            }

                            // Maximum
                            if ( ! empty( $_GET[$filter['meta']]['max'] ) ) {
                                $filter_meta[$filter['meta']][] = array(
                                    array(
                                        'key'       => $filter['meta'],
                                        'value'     => $_GET[$filter['meta']]['max'],
                                        'compare'   => '<=',
                                        'type'      => 'NUMERIC',
                                    ),
                                );
                            }

                            // Minimum & Maximum
                            if ( ! empty( $_GET[$filter['meta']]['min'] ) && ! empty( $_GET[$filter['meta']]['max'] ) ) {
                                $filter_meta[$filter['meta']][] = array(
                                    array(
                                        'key'       => $filter['meta'],
                                        'value'     => array( $_GET[$filter['meta']]['min'], $_GET[$filter['meta']]['max'] ),
                                        'compare'   => 'BETWEEN',
                                        'type'      => 'NUMERIC',
                                    ),
                                );
                            }
                            
                        }

                    }
                }

                // Return the 'meta_query' with the meta data from earlier
                if ( 1 > count($filter_meta) ) {
                    $filter_query['meta_query'] = array(
                        'relation' => 'AND',
                        $filter_meta
                    );
                } else {
                    $filter_query['meta_query'] = array(
                        $filter_meta
                    );                    
                }

            }

            // Query: Orderby
            if ( !empty($_GET['orderby']) ) {
                $value = explode(':', $_GET['orderby']);
                $meta_key = $value[0];
                $order = strtoupper($value[1]);

                $standard = ['ID', 'author', 'title', 'name', 'date', 'modified', 'parent', 'rand', 'comment_count'];

                if ( in_array($meta_key, $standard) ) {
                    $filter_query['orderby'] = $meta_key;
                } else {
                    $filter_query['orderby'] = 'meta_value_num';
                    $filter_query['meta_key'] = $meta_key;
                }

                $filter_query['order'] = $order;
            }

            // Query: Posts Per Page
            if ( !empty($_GET['posts_per_page']) ) {

                $filter_query['posts_per_page'] = $_GET['posts_per_page'];
            }

            // Query: Search
            if ( !empty($_GET['search']) ) {
                $filter_query['s'] = $_GET['search'];
            }

            // WP_Query
            $output = new WP_Query( $filter_query );
            
            // Return Query
            return $output;

        }

        /**
         * Set Query Vars
         */
        public static function set_query_vars( $filter_query ) {

            // Check if Template is Buy
            $buy_template = get_option( 'ysd-mapi_buy_template' );

            // Check if Template is Rent
            $rent_template = get_option( 'ysd-mapi_rent_template' );

            /* Offer: Koop */
            if ( is_page( $buy_template ) ) {
                set_query_var( 'offer', __( 'buy', YSD_MAPI_TEXT_DOMAIN ));
            }

            /* Offer: Huur */
            if ( is_page( $rent_template ) ) {
                set_query_var( 'offer', __( 'rent', YSD_MAPI_TEXT_DOMAIN ) );
            }

            return $filter_query;

        }


        /**
         * Custom Queries
         */
        public static function do_custom_queries( $filter_query ) {

            // When '$_GET' not empty
            if ( ! empty( $_GET ) ) {
                
                // Create meta array
                $filter_meta = array();
                
                // Create loop of all meta from '$_GET'
                foreach ( $_GET as $key => $value ) {

                    // Map Keys with Meta
                    switch ( $key ) {
                        // case 'offer':
                        //     $key = 'aanbod';
                        //     break;
                        // case 'city':
                        //     $key = 'stad';
                        //     break;
                        case 'price':
                            $key = 'prijs';
                            break;
                        case 'sale_status':
                            $key = 'status';
                            break;
                        case 'usable_area':
                            $key = 'woonopp';
                            break;
                        case 'plot_area':
                            $key = 'perceelopp';
                            break;
                        case 'number_of_rooms':
                            $key = 'kamer';
                            break;
                        case 'number_of_bedrooms':
                            $key = 'slaapkamer';
                            break;
                        case 'type':
                            $key = 'type';
                            break;
                    }

                    

                    // Only if '$key' isset and '$value' not empty
                    if ( isset( $mapiPF[$key] ) && ! empty( $value ) && 'zoek' != $key ) {
                        $filter = $mapiPF[$key];
                        
                        // Create variable with all meta
                        if ( ! is_array( $value ) ) {
                            
                            $filter_meta[$filter['meta']] = array(
                                'key' => $filter['meta'],
                                'value' => $value,
                                'compare' => $filter['compare'],
                                'type' => $filter['meta_type'] ?? null,
                            );

                            // Query: Sale Status
                            if ( !empty($_GET['status']) ) {
                                $value = explode(',', $_GET['status']);
                                $filter_meta['sale_status'] = array(
                                    'key' => 'sale_status',
                                    'value' => $value,
                                    'compare' => 'IN',
                                );
                            }

                        } else if ( is_array( $value ) ) {

                            // Minimum
                            if ( ! empty( $_GET[$key]['min'] ) ) {
                                $filter_meta[$filter['meta']][] = array(
                                    array(
                                        'key'       => $filter['meta'],
                                        'value'     => $_GET[$key]['min'],
                                        'compare'   => '>=',
                                        'type'      => 'NUMERIC',
                                    ),
                                );
                            }

                            // Maximum
                            if ( ! empty( $_GET[$key]['max'] ) ) {
                                $filter_meta[$filter['meta']][] = array(
                                    array(
                                        'key'       => $filter['meta'],
                                        'value'     => $_GET[$key]['max'],
                                        'compare'   => '<=',
                                        'type'      => 'NUMERIC',
                                    ),
                                );
                            }

                            // Minimum & Maximum
                            if ( ! empty( $_GET[$key]['min'] ) && ! empty( $_GET[$key]['max'] ) ) {

                                $filter_meta[$filter['meta']][] = array(
                                    array(
                                        'key'       => $filter['meta'],
                                        'value'     => array( $_GET[$key]['min'], $_GET[$key]['max'] ),
                                        'compare'   => 'BETWEEN',
                                        'type'      => 'NUMERIC',
                                    ),
                                );
                            }
                            
                        }

                    }
                }

                // Return the 'meta_query' with the meta data from earlier
                if ( count($filter_meta) > 1 ) {
                    $filter_query['meta_query'] = array(
                        'relation' => 'AND',
                        $filter_meta
                    );
                } else {
                    $filter_query['meta_query'] = array(
                        $filter_meta
                    );                    
                }

            }

            return $filter_query;

        }


        /**
         * Default Queries
         */
        public static function do_default_queries( $filter_query ) {

            // Query: Orderby
            if ( !empty($_GET['orderby']) ) {
                $value = explode(':', $_GET['orderby']);
                $meta_key = $value[0];
                $meta_key = 'status' == $meta_key ? 'sale_status' : $meta_key;
                $order = strtoupper($value[1]);

                $standard = ['ID', 'author', 'title', 'name', 'date', 'modified', 'parent', 'rand', 'comment_count'];

                if ( in_array($meta_key, $standard) ) {
                    $filter_query['orderby'] = $meta_key;
                } else {
                    $filter_query['orderby'] = 'meta_value_num';
                    $filter_query['meta_key'] = $meta_key;
                }

                $filter_query['order'] = $order;
            }

            // Query: Posts Per Page
            if ( !empty($_GET['amount']) ) {

                $filter_query['posts_per_page'] = $_GET['amount'];
            }

            // Query: Search
            if ( !empty($_GET['zoek']) ) {
                $filter_query['s'] = $_GET['zoek'];
            }

            return $filter_query;

        }


        /**
         * Pretty Permalinks
         */
        public static function do_pretty_permalinks( $filter_query ) {

            $filter_tax = array();

            // Get Query Vars
            $qv_offer = get_query_var( 'offer' );
            $qv_city = get_query_var( 'city' );
            
            // For Multiple Cities
            $qv_city = !empty( $qv_city ) ? explode( ',', $qv_city ) : '';

            // Offer
            if ( !empty( $qv_offer ) ) {
                $filter_tax['offer'] = array(
                    'taxonomy' => 'offer',
                    'field' => 'slug',
                    'terms' => $qv_offer,
                );
            }

            // City
            if ( !empty( $qv_city )  ) {
                $filter_tax['city'] = array(
                    'taxonomy' => 'city',
                    'field' => 'slug',
                    'terms' => $qv_city,
                );
            }

            // Return the 'tax_query' with the tax data from earlier
            if ( count($filter_tax) == 1 ) {
                $filter_query['tax_query'] = array(
                    $filter_tax
                );
            } else if ( count($filter_tax) > 1 ) {
                $filter_query['tax_query'] = array(
                    'relation' => 'AND',
                    $filter_tax
                );
            }

            return $filter_query;

        }

    }

}