<?php

namespace ysdmapi\includes;

require YSD_MAPI_PLUGIN_PATH . 'vendor/deliciousbrains/wp-background-processing/classes/wp-async-request.php';
require YSD_MAPI_PLUGIN_PATH . 'vendor/deliciousbrains/wp-background-processing/classes/wp-background-process.php';

class ImportProperty extends \WP_Background_Process
{
    protected $action = 'import_property';

    private MediaLoader $mediaLoader;

    private PropertyHandler $propertyHandler;

    public function __construct($property_handler)
    {
        parent::__construct();

        $this->mediaLoader = new MediaLoader();
        $this->propertyHandler = $property_handler;

    }

    public function task($media)
    {
        
        $extension = pathinfo(strtok($media['url'], '?'))['extension'];
        $media_alias = ( !empty($media['property_id']) && !empty($media['id']) ) ? $media['property_id'] .'-'. $media['id'] .'.'. $extension : '';
        $attachment_id = $this->mediaLoader->sideload_url($media['url'], $media['source'], $media_alias, $media['property_id']);

        $status = $this->propertyHandler->status_log->get_content();

        if(!isset($status['media_progress'])) {
            $status['media_progress'] = 0;
        }

        $this->propertyHandler->status_log->add_content([
            'messages' => [
                [
                    'code' => 'media_import_start',
                    'timestamp' => time(),
                    'message' => __( 'Importing:', YSD_MAPI_TEXT_DOMAIN ) .' '. $media_alias,
                    'severity_level' => 'info',
                    'category' => 'media',
                    'data' => [
                        'url' => $media['url'],
                        'property_id' => $media['property_id'],
                    ],
                ],
            ],
        ]);

        if(is_wp_error($attachment_id))
        {
            $this->propertyHandler->status_log->add_content([
                'messages' => [
                    [
                        'code' => $attachment_id->get_error_code(),
                        'timestamp' => $attachment_id->get_error_data()['timestamp'] ?? null,
                        'message' => $attachment_id->get_error_message(),
                        'severity_level' => $attachment_id->get_error_data()['severity_level'] ?? null,
                        'category' => 'media',
                        'data' => $attachment_id->get_error_data(),
                    ],
                ],
            ]);
        }
        else
        {
            $this->propertyHandler->status_log->add_content([
                'messages' => [
                    [
                        'code' => 'media_import_success',
                        'timestamp' => time(),
                        'message' => __( 'Imported:', YSD_MAPI_TEXT_DOMAIN ) .' '. $media_alias,
                        'severity_level' => 'info',
                        'category' => 'media',
                        'data' => [
                            'url' => $media['url'],
                            'property_id' => $media['property_id'],
                            'attachment_id' => $attachment_id,
                        ],
                    ],
                ],
            ]);
        }

        $this->propertyHandler->status_log->update_content(['media_progress' => $status['media_progress'] + 1]);

        return false;

    }

    protected function complete()
    {
        parent::complete();

        $status = $this->propertyHandler->status_log->get_content();

        $this->propertyHandler->status_log->update_content(['index' => $status['index'] + 1]);
        $this->propertyHandler->process_next_property();

    }

}