<?php

namespace ysdmapi\includes;

class JsonLog
{
    protected string $file_path;

    protected int $time;

    protected bool $date_seperated;

    /**
     * Undocumented function
     *
     * @param string $directory_path
     * @param string $name
     * @param boolean $date_seperated_directories
     * @param integer $time
     */
    public function __construct(string $directory_path, string $name, bool $date_seperated_directories = true, int $time = null)
    {
        $time = $time ?? time();
        
        $file_path = trailingslashit($directory_path);
        $file_path .= $date_seperated_directories ? date('Y/m/d/', $time) : '';
        $file_path .= $name . '_' . $time . '.log';

        /*
         * Increment a second when a log with the same name already exists for that timestamp. 
         * this might be the case when multiple logs are made within the same second. 
        */
        while(file_exists($file_path))
        {
            $time++;
            $file_path = trailingslashit($directory_path) . $name . '_' . $time . '.log';
        }

        $this->file_path = $file_path;
        $this->time = $time;
        $this->date_seperated = $date_seperated_directories;

    }

    /**
     * Update the content of the Json log
     *
     * @param array $new_content
     * The content you want to add/update to the log as an associative array
     * @return void
     */
    public function update_content(array $new_content) : void
    {
        $this->create_log_file_if_not_exist();

        $content = json_decode(file_get_contents($this->file_path), true);
        
        if($content)
        {
            $new_content = array_merge($content, $new_content);
        }

        file_put_contents($this->file_path, json_encode($new_content));

    }

        /**
     * Update the content of the Json log
     *
     * @param array $new_content
     * The content you want to add/update to the log as an associative array
     * @return void
     */
    public function add_content(array $new_content) : void
    {
        $this->create_log_file_if_not_exist();

        $content = json_decode(file_get_contents($this->file_path), true);
        
        if($content)
        {
            $new_content = array_merge_recursive($content, $new_content);
        }

        file_put_contents($this->file_path, json_encode($new_content));

    }

    /**
     * Get the content from the Json log
     *
     * @param boolean $decode
     * If set to true the content will be returned as an associative array
     * otherwise it will return a string
     * 
     * @return mixed
     * A string, an array or false on failure
     */
    public function get_content(bool $decode = true)
    {
        $content = file_get_contents($this->file_path);

        if($decode)
        {
            $content = json_decode($content, true);
        }

        return $content;

    }

    public function get_timestamp() : int
    {
        return $this->time;
    }

    private function create_log_file_if_not_exist()
    {
        if(!file_exists($this->file_path))
        {
            $dirname = dirname($this->file_path);

            // Ensure the directory exists
            if (!is_dir($dirname))
            {
                mkdir($dirname, 0755, true);
            }

            // Create the file
            $file = fopen($this->file_path, 'w');

            fclose($file);
        }

    }

}