<?php

// namespace ysdmapi\includes;

/**
 * Checks if the user is allowed to use the plugin
 * 
 * @since      1.0.0
 *
 * @package    ysdmapi
 * @subpackage ysdmapi/includes
 */
class UserValidation {
    
    public function __construct() {

        add_action('admin_init', array($this, 'register_options'));

        add_filter('cron_schedules', function($s) {
            $s['ysd-mapi-daily'] = array(
                'interval' => 86400,
                'display' => __('Yourstyle MAPI - Daily', YSD_MAPI_TEXT_DOMAIN)
            );
            return $s;
        });        

        add_action('ysd_mapi_telemetry', array($this, 'cron_telemetry'));
        if (!wp_next_scheduled('ysd_mapi_telemetry')) {
            wp_schedule_event(time(), 'ysd-mapi-daily', 'ysd_mapi_telemetry');
        }

        add_action('init', array($this, 'add_api'), 10);
    }

    public function register_options() {
        register_setting('ysd-mapi', 'ysd-mapi_license_state');
        add_option('ysd-mapi_license_state', '0');

        register_setting('ysd-mapi', 'ysd-mapi_license_token');
        add_option('ysd-mapi_license_token', '0');
    }

    public static function run_validation_check() {
        if (get_option('ysd-mapi_license_token') == '0') {
            $a = random_bytes(20);
            update_option('ysd-mapi_license_token', bin2hex($a));
        }

        $c = curl_init();
        curl_setopt($c, CURLOPT_URL, 'https://makelaarsapi.nl/api/verify-token');
        curl_setopt($c, CURLOPT_HEADER, false);
        curl_setopt($c, CURLOPT_RETURNTRANSFER, true);
        
        curl_setopt($c, CURLOPT_ENCODING, '');
        curl_setopt($c, CURLOPT_MAXREDIRS, 10);

        curl_setopt($c, CURLOPT_FOLLOWLOCATION, true);
        curl_setopt($c, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_1);
        curl_setopt($c, CURLOPT_SSL_VERIFYHOST, false);
        curl_setopt($c, CURLOPT_SSL_VERIFYPEER, false);

        curl_setopt($c, CURLOPT_TIMEOUT, 60);
        
        curl_setopt($c, CURLOPT_CUSTOMREQUEST, 'POST');

        curl_setopt($c, CURLOPT_POSTFIELDS, http_build_query(array(
            'blogname'      => get_option('blogname'),
            'siteurl'       => get_option('siteurl'),
            'admin_email'   => get_option('admin_email'),
            'plugin_ver'    => YSD_MAPI_VERSION,
            'wordpress_ver' => get_bloginfo('version'),
            'token'         => get_option('ysd-mapi_license_token'),
        )));

        curl_setopt($c, CURLOPT_USERAGENT, 'Yourstyle MAPI - Wordpress Plugin');

        $r = curl_exec($c);
        $r = json_decode($r, true);
        return $r;
    }

    public static function check_validation() {
        if (get_option('ysd-mapi_license_state') == 'valid') {
            return TRUE;
        } else {
            return FALSE;
        }
    }

    public static function check_validation_state() {
        $v = get_option('ysd-mapi_license_state');
        if ($v == 0) {
            $v = 'invalid';
        } else {
            return $v;
        }
    }

    public static function validation_warning() {
        $v = get_option('ysd-mapi_license_state');
        switch ($v) {
            case 'wait-approval':
                return __('Your license is currently waiting for approval. Your license needs to be approved before you can start using the plugin.', YSD_MAPI_TEXT_DOMAIN);
                break;

            case 'valid':
                return __('Your license is valid. Please refresh this page.', YSD_MAPI_TEXT_DOMAIN);
                break;               
            
            default:
                return __('Your license is invalid. Without a license you cannot access all features and will not receive any updates. Please contact your admin for more information.', YSD_MAPI_TEXT_DOMAIN);
                break;
        }
    }

    public function cron_telemetry() {
        $r = $this->run_validation_check();
        if (isset($r['state'])) {
            if ($r['state'] == 'wait-approval' || $r['state'] == 'invalid' || $r['state'] == 'valid') {
                update_option('ysd-mapi_license_state', $r['state']);
            } else {
                update_option('ysd-mapi_license_state', 'invalid');
            }
        } else {
            update_option('ysd-mapi_license_state', 'invalid');
        }
    }

    public function add_api() {
        add_feed('ysdmapi-api/state', array($this, 'api_endpoint_state'));
        // add_feed('ysdmapi-api/force_setting', array($this, 'api_endpoint_force_setting'));
    }

    public function api_endpoint_state() {
        header("Content-Type: application/json; charset=UTF-8");
        if (isset($_POST['token'])) {
            if ($_POST['token'] == get_option('ysd-mapi_license_token')) {
                if (isset($_POST['state']) && !empty($_POST['state'])) {
                    update_option('ysd-mapi_license_state', $_POST['state']);
                }
            }
        }
        echo json_encode(':)');
    }
    
}
new UserValidation();