<?php

namespace ysdmapi\includes\custom_fields;

class CustomFieldGroup
{
    protected string $id;

    protected string $label;

    protected string $description;

    protected $pages;

    protected $parent;

    protected array $fields;

    public function __construct($id, $label, $description='', $pages = array())
    {
        $this->id = $id;
        $this->label = $label;
        $this->description = $description;
        $this->pages = $pages;
        $this->fields = array();
        $this->parent = null;

    }

    public function display()
    {
        $data['field_group'] = $this;

        include plugin_dir_path(__FILE__) . 'partials/field_groups/default.php';
        
    }

    public function add_field(CustomField $field) : void
    {
        $field->parent = $this;
        foreach($this->pages as $page)
        {
            $field->pages[] = $page;
        }
        $this->fields[$field->id] = $field;
    }

    public function get_id() : string
    {
        return $this->id;
    }

    public function get_label() : string
    {
        return $this->label;
    }
    public function set_label(string $label) : void
    {
        $this->label = $label;
    }

    public function get_description() : string
    {
        return $this->description;
    }
    public function set_description($description) : void
    {
        $this->description = $description;
    }

    public function get_pages()
    {
        return $this->pages;
    }
    public function add_pages($pages)
    {
        $pages = is_array($pages) ? $pages : array($pages);

        foreach($pages as $page)
        {
            $this->pages[] = $page;
        }

        foreach($this->fields as $field)
        {
            foreach($pages as $page)
            {
                $field->pages[] = $page;
            }
        }

    }

    public function get_parent()
    {
        return $this->parent;
    }
    public function set_parent($parent)
    {
        $this->parent = $parent;
    }

    public function get_fields() : array
    {
        return array_values($this->fields);
    }

    public function get_field($field_id)
    {
        return $this->fields[$field_id] ?? null;
    }

}