<?php

namespace ysdmapi\includes\custom_fields;

class CustomFieldsHandler
{
    protected array $metaboxes;

    protected array $field_groups;

    protected array $fields;

    protected array $pages;

    protected string $prefix = 'ysd-mapi';

    public function __construct()
    {
        $this->metaboxes = array();
        $this->field_groups = array();
        $this->fields = array();
        $this->pages = array();

    }

    #region CustomMetaBoxes
    public function add_metabox(CustomMetaBox $customMetaBox) : void
    {
        $this->metaboxes[$customMetaBox->id] = $customMetaBox;

        $this->add_object_to_pages($customMetaBox->screens, 'meta_boxes', $customMetaBox->id, $customMetaBox->type);

        foreach($customMetaBox->get_field_groups() as $field_group)
        {
            $this->add_field_group($field_group);
        }

    }

    public function register_meta_boxes() : void
    {
        foreach($this->metaboxes as $metabox)
        {
            $metabox->register();
        }

    }

    public function save_meta_boxes($post_id) : void
    {
        foreach($this->metaboxes as $metabox)
        {
            $metabox->save_fields($post_id);
        }
    }

    public function get_metaboxes() : array
    {
        return array_values($this->metaboxes);
    }

    public function get_pages() : array
    {
        return $this->pages;
    }

    public function get_metabox($metabox_id)
    {
        return $this->metaboxes[$metabox_id] ?? null;
    }
    #endregion

    #region CustomFieldGroups
    public function add_field_group(CustomFieldGroup $customFieldGroup) : void
    {
        $this->field_groups[$customFieldGroup->get_id()] = $customFieldGroup;

        $this->add_object_to_pages($customFieldGroup->get_pages(), 'field_groups', $customFieldGroup->get_id(), 'default', $customFieldGroup->get_parent());

        foreach($customFieldGroup->get_fields() as $field)
        {
            $this->add_field($field);
        }

    }

    public function create_field_groups_by_array(array $array) : array
    {
        $field_groups = array();

        foreach($array as $group_id => $group_args)
        {
            $field_group = new CustomFieldGroup($group_id, $group_args['label'], 
            $group_args['description'] ?? '', $group_args['pages'] ?? array());
            $fields = $this->create_fields_by_array($group_args['fields']);

            foreach($fields as $field)
            {
                $field_group->add_field($field);
            }

            $field_groups[] = $field_group;
        }

        return $field_groups;

    }

    public function get_field_groups() : array
    {
        return array_values($this->field_groups);
    }

    public function get_field_group($group_id)
    {
        return $this->field_groups[$group_id] ?? null;
    }
    #endregion

    #region CustomFields
    public function add_field(CustomField $customField) : void
    {
        $this->fields[$customField->id] = $customField;

        $this->add_object_to_pages($customField->pages, 'fields', $customField->id, $customField->type, $customField->parent);

    }

    public function get_fields() : array
    {
        return array_values($this->fields);
    }

    public function create_fields_by_array(array $array) : array
    {
        $fields = array();

        foreach($array as $field_id => $field_args)
        {
            $fields[] = new CustomField(
                $field_id,
                $field_args['label'],
                $field_args['type'],
                $field_args['validation'] ?? null,
                $field_args['default_value'] ?? null,
                $field_args['options'] ?? null,
                $field_args['emptyLabelMin'] ?? null,
                $field_args['emptyLabelMax'] ?? null,
                $field_args['optionsMin'] ?? null,
                $field_args['optionsMax'] ?? null,
                $field_args['description'] ?? null,
                $field_args['attributes'] ?? null,
                $field_args['condition'] ?? null,

            );
        }

        return $fields;

    }

    public function get_field($field_id)
    {
        return $this->fields[$field_id] ?? null;
    }
    #endregion

    #region enqueue
    public function enqueue_styles() : void
    {
        $this->page_enqueue('styles');
    }

    public function enqueue_scripts() : void
    {
        $this->page_enqueue('scripts');
    }

    private function page_enqueue(string $enqueue) : void
    {
        $page = $this->current_page_in_pages();

        if($page)
        {
            foreach($this->pages[$page] as $object_type => $objects)
            {
                foreach($objects['types'] as $field_type)
                {
                    $handle = $object_type . '_' . $field_type;

                    switch($enqueue)
                    {
                        case 'styles' :
                            $static_path = 'css/' . $object_type . '/' . $field_type . '.css';

                            if(file_exists(plugin_dir_path(__FILE__) . $static_path))
                            {
                                wp_enqueue_style($handle, plugin_dir_url(__FILE__) . $static_path);
                            }
                        break;
                            
                        case 'scripts' :
                            $static_path = 'js/' . $object_type . '/' . $field_type . '.js';

                            if(file_exists(plugin_dir_path(__FILE__) . $static_path))
                            {
                                wp_enqueue_script($handle, plugin_dir_url(__FILE__) . $static_path);
                            }
                        break;
                    }
                }
            }

            wp_enqueue_style('fields_default', plugin_dir_url(__FILE__) . 'css/fields/default.css');
            wp_enqueue_script('fields_default', plugin_dir_url(__FILE__) . 'js/fields/default.js');
        }

    }
    #endregion

    #region pages
    public function display_page_fields($page = null) : void
    {
        if(!isset($page))
        {
            $page = $this->current_page_in_pages();
        }

        if(array_key_exists($page, $this->pages))
        {
            foreach($this->pages[$page] as $object_type => $objects)
            {
                foreach($objects['ids'] as $id)
                {
                    switch($object_type)
                    {
                        case 'field_groups':
                            $this->field_groups[$id]->display();
                        break;

                        case 'fields':
                            $this->fields[$id]->display();
                        break;
                    }
                }
            }
        }

    }

    public function get_page_fields($page = null) : array
    {
        $result = array();

        if(!isset($page))
        {
            $page = $this->current_page_in_pages();
        }

        if($page)
        {
            foreach($this->pages[$page] as $object_type => $objects)
            {
                foreach($objects['ids'] as $id)
                {
                    switch($object_type)
                    {
                        case 'field_groups':
                            $result['field_groups'][] = $this->field_groups[$id];
                        break;

                        case 'fields':
                            $result['fields'][] = $this->fields[$id];
                        break;

                        case 'meta_boxes':
                            $result['meta_boxes'][] = $this->metaboxes[$id];
                        break;
                    }
                }
            }
        }

        return $result;
    }

    private function add_object_to_pages($pages, $object_type, $id, $type = 'default', $parent = null) : void
    {
        $pages_array = is_array($pages) ? $pages : array($pages);

        foreach($pages_array as $page)
        {
            if(!array_key_exists($page, $this->pages))
            {
                $this->pages[$page][$object_type]['ids'] = array();
                $this->pages[$page][$object_type]['types'] = array();
            }

            if(!array_key_exists($object_type, $this->pages[$page]))
            {
                $this->pages[$page][$object_type]['ids'] = array();
                $this->pages[$page][$object_type]['types'] = array();
            }

            if(!isset($parent) && !in_array($id, $this->pages[$page][$object_type]['ids']))
            {
                $this->pages[$page][$object_type]['ids'][] = $id;
            }

            if(!in_array($type, $this->pages[$page][$object_type]['types']))
            {
                $this->pages[$page][$object_type]['types'][] = $type;
            }
        }

    }

    private function current_page_in_pages()
    {
        $result = false;

        global $pagenow;
        global $plugin_page;
        $current_screen = get_current_screen()->id;
        $template_page = null;

        $post_type = get_post_type();
        if($post_type)
        {
            if(is_post_type_archive($post_type))
            {
                $template_type = 'archive';
            }
            else if(is_singular($post_type))
            {
                $template_type = 'single';
            }

            if(isset($template_type))
            {
                $template_page = $template_type . '-' . $post_type;
            }
        }

        $possible_current_pages = [$plugin_page, $current_screen, $template_page, $pagenow];

        foreach($possible_current_pages as $page)
        {   
            if($this->page_in_pages($page))
            {
                $result = $page;
                break;
            }
        }

        return $result;

    }

    private function page_in_pages($page) : bool
    {
        if(isset($page) && !empty($page))
        {
            $result = array_key_exists($page, $this->pages);
        }
        else
        {
            $result = false;
        }

        return $result;

    }
    #endregion

}