/**
 * Run a callbck after DOM is loaded
 * 
 * @param {callable} fn
 * Callback to run 
 */
function docReady(fn) {
    // see if DOM is already available
    if (document.readyState === "complete" || document.readyState === "interactive") {
        // call on next available tick
        setTimeout(fn, 1);
    } else {
        document.addEventListener("DOMContentLoaded", fn);
    }
}

/**
 * Operator string to method mapping, so dynamic operators are possible
 */
var operatorToMethod = {
    '=': function (a, b) {
        return a == b
    },
    '!': function (a, b) {
        return a != b
    },
    '<': function (a, b) {
        return a < b
    },
    '<=': function (a, b) {
        return a <= b
    },
    '>': function (a, b) {
        return a > b
    },
    '>=': function (a, b) {
        return a >= b
    },
};

/**
 * Loops through the given fields and hides them if needed
 * 
 * @param {Array} fields 
 */
function hideFieldsByCondition(fields) {
    fields.forEach(function (field) {
        /* Get the conditional variables from the data attributes of the field node */
        let compareField = field.dataset.conditionField;
        let operator = field.dataset.conditionCompare;
        let compareValue = field.dataset.conditionValue;

        let compareFieldNode = document.querySelector('[id*="' + compareField + '"]');

        if (!compareFieldNode) {
            console.log('Notice: compare field: *' + compareField + ' not found for conditional field: ' + field.querySelector('[id]').id);

            return;
        }

        /* Show or hide the conditional field based on the condition */
        if (!operatorToMethod[operator](compareFieldNode.value, compareValue)) {
            field.style.display = "none";
        } else {
            field.style.display = "block";
        }
    });

}

/* Scripts that run after DOM is loaded */
docReady(function () {
    /* Fields that are hidden depending on the value of another ("comparison") field */
    var conditionalFields = document.querySelectorAll('.mapi-filter__field[data-condition-compare]');
    /* List of fields where conditional fields are listening to */
    var comparisonFields = [];

    /* 
     * Loop through all conditionalfields and add all there comparison fields to a variable
     * so an event listener can be added to them
     */
    conditionalFields.forEach(function (field) {
        compareField = field.dataset.conditionField;

        if (compareField) {
            compareFieldNode = document.querySelector('[id*="' + compareField + '"]');

            if (compareFieldNode) {
                comparisonFields.push(compareFieldNode);
            }
        }
    });

    comparisonFields.forEach(function (field) {
        /* On comparison field change hide conditional field */
        field.addEventListener("change", function () {
            hideFieldsByCondition(conditionalFields);
        });
    });

    /* Hide the conditional fields on start */
    hideFieldsByCondition(conditionalFields);

});