<?php

namespace ysdmapi\includes\post_models;

use Exception;
use WP_Error;
use WP_Post;
use WP_Query;

//@todo create interface from this class
class Property
{
    private $id;

    private $content;

    private array $attachments;
    private array $attachments_to_keep;

    private array $meta_values;

    private array $mappings;


    public function __construct($id = NULL, $content = '', array $meta_values = array(), bool $map_meta = true)
    {
        $this->mappings = array(
            'id' => 'external_id',
        );

        $this->meta_values = $map_meta ? $this->map_meta_values($meta_values) : $meta_values;

        if(!isset($id) && isset($this->meta_values['external_id']))
        {
            $this->id = $this->get_id_by_external();
        } else {
            $this->id = $id;
        }

        $this->attachments = $this->get_db_attachments();
        $this->attachments_to_keep = array();

        $this->content = $content;

    }

    public function save()
    {
        $result = false;

        if($this->needs_updating())
        {
            $result = wp_insert_post($this->to_postarr(), true);

            if(!is_wp_error($result) && $result !== 0)
            {
                $this->id = $result;
            }

            // Update Meta: City
            $this->update_meta_city();

            // Update Meta: Province
            $this->update_meta_province();

            // Update Meta: Price
            $this->update_meta_price();

            // Process Taxonomy: Agency
            $this->process_tax_agency();

            // Process Taxonomy: Offer
            $this->process_tax_offer();

            // Process Taxonomy: City
            $this->process_tax_city();

            // Format and Update Price
            if ( isset( $this->meta_values['price'] ) ) {
                // Format Price
                $price = str_replace( ',', '', $this->meta_values['price'] );
                if ( $price ) {
                    // Update Price Meta
                    update_post_meta( $this->id, 'price', $price );
                }
            }

            $reva = get_option( 'ysd-mapi_api_handler_url', 0 );
            if ( $reva == 1 ) {
                // Recreational Agency Name
                if ( isset( $this->meta_values['agency_name'] ) ) {
                    // Get Term By Slug
                    $term = get_term_by('slug', $this->meta_values['agency_name'], 'agency');

                    if ( ! is_wp_error( $term ) ) {
                        if ( ! empty( $term ) && $term !== false ) {

                            // Set Post Terms To Taxonomy
                            wp_set_post_terms($this->id, $term->term_id, 'agency');

                        } else {

                            // Insert Term Into Taxonomy
                            wp_insert_term($this->meta_values['agency_name'], 'agency');

                            // Get Term By Slug
                            $term = get_term_by('slug', $this->meta_values['agency_name'], 'agency');

                            // Set Post Terms To Taxonomy
                            wp_set_post_terms($this->id, $term->term_id, 'agency');

                        }
                    }
                }
            }

        }

        return $result;

    }

    /**
     * Taxonomy - Agency
     * 
     * Add Agencies to Taxonomy 'agency'.
     */
    public function process_tax_agency() {

        if ( isset( $this->meta_values['agency_name'] ) ) {
            
            // Get Term By Slug
            $term = get_term_by('slug', $this->meta_values['agency_name'], 'agency');
            
            if ( ! is_wp_error( $term ) ) {
                if ( ! empty( $term ) && $term !== false ) {
                    
                    // Set Post Terms To Taxonomy
                    wp_set_post_terms($this->id, $term->term_id, 'agency');
                    
                } else {
                    
                    // Insert Term Into Taxonomy
                    wp_insert_term($this->meta_values['agency_name'], 'agency');
                    
                    // Get Term By Slug
                    $term = get_term_by('slug', $this->meta_values['agency_name'], 'agency');
                    
                    // Set Post Terms To Taxonomy
                    wp_set_post_terms($this->id, $term->term_id, 'agency');
                    
                }
            }
        }
    }

        /**
     * Meta - City
     * 
     * Make 'city' meta ucfirst() & strtolower().
     */
    public function update_meta_city() {

        if ( isset( $this->meta_values['city'] ) ) {
            $city = ucfirst( strtolower( $this->meta_values['city'] ) );
            if ( $city ) {
                update_post_meta( $this->id, 'city', $city );
            }
        }
    }

    /**
     * Meta - Province
     * 
     * Make 'province' meta ucwords() & str_replace().
     */
    public function update_meta_province() {

        if ( isset( $this->meta_values['province'] ) ) {
            $province = ucwords(str_replace( '_', '-', $this->meta_values['province'] ), '-');
            if ( $province ) {
                update_post_meta( $this->id, 'province', $province );
            }
        }
    }

    /**
     * Meta - Price
     * 
     * Remove comma from 'price' meta.
     */
    public function update_meta_price() {

        if ( isset( $this->meta_values['price'] ) ) {
            $price = str_replace( ',', '', $this->meta_values['price'] );
            if ( $price ) {
                update_post_meta( $this->id, 'price', $price );
            }
        }
    }

    /**
     * Meta - Sale Type
     * 
     * Change 'sale_type' meta to 'offer'.
     */
    public function change_meta_sale_type() {

        $sale_type = isset( $this->meta_values['sale_type'] ) ? $this->meta_values['sale_type'] : '';

        if ( ! empty( $sale_type ) ) {
            delete_post_meta( $this->id, 'sale_type' );
            update_post_meta( $this->id, 'offer', $sale_type );
        }
    }

    /**
     * Taxonomy - Offer
     * 
     * Add Offers to Taxonomy 'offer'.
     */
    public function process_tax_offer() {

        if ( isset( $this->meta_values['sale_type'] ) ) {
            
            $meta = $this->meta_values['sale_type'];
            switch($meta) {
                case '1':
                    $value = __( 'Buy', YSD_MAPI_TEXT_DOMAIN );
                    break;
                case '2':
                    $value = __( 'Rent', YSD_MAPI_TEXT_DOMAIN );
                    break;
            }
            
            // Get Term By Slug
            $term = get_term_by('slug', $value, 'offer');

            if ( ! is_wp_error( $term ) ) {
                if ( ! empty( $term ) && $term !== false ) {

                    // Set Post Terms To Taxonomy
                    wp_set_post_terms($this->id, $term->term_id, 'offer');

                } else {

                    // Insert Term Into Taxonomy
                    wp_insert_term($value, 'offer');

                    // Get Term By Slug
                    $term = get_term_by('slug', $value, 'offer');

                    // Set Post Terms To Taxonomy
                    wp_set_post_terms($this->id, $term->term_id, 'offer');

                }
            }
        }
    }

    /**
     * Taxonomy - City
     * 
     * Add Cities to Taxonomy 'city'.
     */
    public function process_tax_city() {

        if ( isset( $this->meta_values['city'] ) ) {

            $city_ucfirst = ucfirst( strtolower( $this->meta_values['city'] ) );
            
            // Get Term By Slug
            $term = get_term_by('slug', $city_ucfirst, 'city');

            if ( ! is_wp_error( $term ) ) {
                if ( ! empty( $term ) && $term !== false ) {

                    // Set Post Terms To Taxonomy
                    wp_set_post_terms($this->id, $term->term_id, 'city');

                } else {

                    // Insert Term Into Taxonomy
                    wp_insert_term($city_ucfirst, 'city');

                    // Get Term By Slug
                    $term = get_term_by('slug', $city_ucfirst, 'city');

                    // Set Post Terms To Taxonomy
                    wp_set_post_terms($this->id, $term->term_id, 'city');

                }
            }
        }
    }

    public function get_db_post_meta() : array
    {
        if(isset($this->id))
        {
            $meta = get_post_meta($this->id);
            $formatted = array();

            foreach ($meta as $key => $value) {
                $formatted[$key] = maybe_unserialize($value[0]);
            }

            return $formatted;
        }
        else
        {
            return array();
        }

    }

    /**
     * Get all the attachments of this property from the database
     *
     * @return array
     */
    public function get_db_attachments() : array
    {
        if(isset($this->id))
        {
            return get_attached_media('', $this->id);
        }
        else
        {
            return array();
        }
    }

    private function map_meta_values(array $meta_values)
    {
        foreach ($this->mappings as $key => $value) {
            if(isset($meta_values[$key]))
            {
                $meta_values[$value] = $meta_values[$key];

                unset($meta_values[$key]);
            }
        }

        return $meta_values;

    }

    private function to_postarr() : array {
        $author = get_option('ysd-mapi_api_author', get_current_user_id());

        $postarr = array(
            'post_author' => $author,
            'post_date' => $this->build_date(),
            'post_content' => $this->content,
            'post_title' => $this->build_title(),
            'post_status' => 'publish',
            'post_type' => 'property',
            'comment_status' => 'closed',
            'ping_status' => 'closed',
            'post_name' => $this->build_permalink(),
            'meta_input' => $this->meta_values,
        );

        if(isset($this->id)) {
            $postarr['ID'] = $this->id;
        }

        return $postarr;

    }

    private function build_date() : string {

        $date = '';

        $date = !empty( $this->meta_values['created_at'] ) ? $this->meta_values['created_at'] : '';
        $date = !empty( $date ) ? date( "Y-m-d H:i:s", strtotime( $date ) ) : '';
        
        return $date == '' ?  '' : $date;

    }

    private function build_title() : string
    {
        //@todo make dynamic based on settings
        $title = '';

        $title .= $this->meta_values['address_1'] ?? '';
        $title .= isset($this->meta_values['house_number']) ? ' ' . $this->meta_values['house_number'] : '';
        $title .= $this->meta_values['house_number_addition'] ?? '';
        $title .= isset($this->meta_values['city']) ? ', ' . ucwords(strtolower($this->meta_values['city']), " \t\r\n\f\v-") : '';
        
        return $title == '' ?  'untitled' : $title;

    }

    private function build_permalink() : string {

        // @todo make dynamic based on settings
        $permalink = '';

        $permalink .= !empty( get_the_id() ) ? get_the_id() : '';
        $permalink .= !empty( $this->meta_values['address_1'] ) ? '-'. $this->meta_values['address_1'] : '';
        $permalink .= !empty( $this->meta_values['house_number'] ) ? '-'. $this->meta_values['house_number'] : '';
        $permalink .= !empty( $this->meta_values['house_number_addition'] ) ? $this->meta_values['house_number_addition'] : '';

        // domain.com/ID-Address-NumberNumberaddition
        return $permalink == '' ?  '' : $permalink;

    }

    /**
     * Look for property inside database that has the external_id and
     * return the id
     *
     * @return int|NULL the id
     */
    private function get_id_by_external()
    {
        $id = NULL;

	    $query = new WP_Query(array(
			'post_type' => 'property',
			'post_per_page' => -1,
			'meta_query' => array(
				array(
				    'key' => 'external_id',
					'compare' => '=',
					'value' => $this->meta_values['external_id'],
				),
			),
        ));

        if($query->have_posts())
        {
            $query->the_post();

            $id = get_the_ID();
        }

        return $id;
        
    }

    /**
     * Checks if the property should be updated, by comparing the
     * current object values with the values from the database
     *
     * @return boolean
     */
    private function needs_updating() : bool
    {
        $needs_updating = true;
        
        if(isset($this->id))
        {
            $old_meta = $this->get_db_post_meta();
            $old_content = get_post_field('post_content', $this->id, 'raw');
            $old_title = get_post_field('post_title', $this->id, 'raw');
            $old_permalink = get_post_field('post_name', $this->id, 'raw');
            $new_content = wp_unslash(sanitize_post_field('post_content', $this->content, $this->id, 'db'));
            $new_title = $this->build_title();
            $new_permalink = $this->build_permalink();
            $sync_api = $old_meta['sync_api'] ?? false;
            
            /**
             * Doesn't need to be updated when sync_api is false or when all values are the same
             */
            if(!$sync_api || (!$this->meta_values_differ($old_meta) && $new_content == $old_content && $new_title == $old_title && $new_permalink == $old_permalink)) {
                $needs_updating = false;
            }
        }

        return $needs_updating;

    }

    /**
     * Checks if the provided meta values have changes compared to the current meta values
     *
     * @param array $old_meta_values
     * The meta values to compare with the current meta values
     * 
     * @return bool
     * True if the provided values are different from the current meta values.
     * False if they are the same.
     */
    private function meta_values_differ(array $old_meta_values) : bool
    {
        $are_different = false;
        
        foreach($this->meta_values as $key => $value)
        {
            if(isset($old_meta_values[$key]))
            {
                if($old_meta_values[$key] != $value)
                {
                    $are_different = true;

                    break;
                }
            }
            else
            {
                $are_different = true;

                break;
            }
        }

        return $are_different;

    }

    public function get_id() : int
    {
        return $this->id;
    }

}