// https://dev.to/pixelgoo/how-to-configure-webpack-from-scratch-for-a-basic-website-46a5
// https://carrieforde.com/webpack-wordpress/
const path = require("path"),
    webpack = require("webpack"),
    MiniCssExtractPlugin = require("mini-css-extract-plugin"),
    RemoveFilesWebpackPlugin = require("remove-files-webpack-plugin");

module.exports = [{
    name: "mapi-archive",
    // Path to your entry point. From this file Webpack will begin his work
    entry: ["./front/assets/src/js/property-archive.js", "./front/assets/src/scss/property-archive.scss"],

    // Path and filename of your result bundle.
    // Webpack will bundle all JavaScript into this file
    output: {
        path: path.resolve(__dirname, "front/assets/dist"),
        filename: "js/property-archive.min.js",
        publicPath: "./front/assets/dist/"
    },
    module: {
        rules: [{
                test: /\.js$/,
                exclude: /(node_modules)/,
                use: {
                    loader: "babel-loader",
                    options: {
                        presets: ["@babel/preset-env"]
                    }
                }
            },
            {
                // Apply rule for .sass, .scss or .css files
                test: /\.(sa|sc|c)ss$/,
                // Set loaders to transform files.
                // Loaders are applying from right to left(!)
                // The first loader will be applied after others
                use: [{
                        // After all CSS loaders we use plugin to do his work.
                        // It gets all transformed CSS and extracts it into separate
                        // single bundled file
                        loader: MiniCssExtractPlugin.loader
                    },
                    {
                        // This loader resolves url() and @imports inside CSS
                        loader: "css-loader"
                    },
                    {
                        // Then we apply postCSS fixes like autoprefixer and minifying
                        loader: "postcss-loader"
                    },
                    {
                        // First we transform SASS to standard CSS
                        loader: "sass-loader",
                        options: {
                            implementation: require("sass")
                        }
                    }
                ]
            },
            {
                test: /\.(png|jpe?g|gif|svg)$/i,
                use: [{
                    loader: "file-loader",
                    options: {
                        name: "[name].[ext]",
                        outputPath: "images"
                    }
                }]
            }
        ]
    },
    plugins: [
        new webpack.DefinePlugin({
            ENV: JSON.stringify("mapi-archive")
        }),
        new MiniCssExtractPlugin({
            filename: "css/property-archive.min.css"
        })
    ]

    // Default mode for Webpack is production.
    // Depending on mode Webpack will apply different things
    // on final bundle. For now we don't need production's JavaScript
    // minifying and other thing so let's set mode to development
    // mode: 'development',
    // watch: true
}, {
    name: "mapi-single",
    // Path to your entry point. From this file Webpack will begin his work
    entry: ["./front/assets/src/js/property-single.js", "./front/assets/src/scss/property-single.scss"],

    // Path and filename of your result bundle.
    // Webpack will bundle all JavaScript into this file
    output: {
        path: path.resolve(__dirname, "front/assets/dist"),
        filename: "js/property-single.min.js",
        publicPath: "../"
    },
    module: {
        rules: [{
                test: /\.js$/,
                exclude: /(node_modules)/,
                use: {
                    loader: "babel-loader",
                    options: {
                        presets: ["@babel/preset-env"]
                    }
                }
            },
            {
                // Apply rule for .sass, .scss or .css files
                test: /\.(sa|sc|c)ss$/,
                // Set loaders to transform files.
                // Loaders are applying from right to left(!)
                // The first loader will be applied after others
                use: [{
                        // After all CSS loaders we use plugin to do his work.
                        // It gets all transformed CSS and extracts it into separate
                        // single bundled file
                        loader: MiniCssExtractPlugin.loader
                    },
                    {
                        // This loader resolves url() and @imports inside CSS
                        loader: "css-loader"
                    },
                    {
                        // Then we apply postCSS fixes like autoprefixer and minifying
                        loader: "postcss-loader"
                    },
                    {
                        // First we transform SASS to standard CSS
                        loader: "sass-loader",
                        options: {
                            implementation: require("sass")
                        }
                    }
                ]
            },
            {
                test: /\.(png|jpe?g|gif|svg)$/i,
                use: [{
                    loader: "file-loader",
                    options: {
                        name: "[name].[ext]",
                        outputPath: "images"
                    }
                }]
            }
        ]
    },
    plugins: [
        new webpack.DefinePlugin({
            ENV: JSON.stringify("mapi-single")
        }),
        new MiniCssExtractPlugin({
            filename: "css/property-single.min.css"
        })
    ]

    // Default mode for Webpack is production.
    // Depending on mode Webpack will apply different things
    // on final bundle. For now we don't need production's JavaScript
    // minifying and other thing so let's set mode to development
    // mode: 'development',
    // watch: true
}, {
    name: 'ysd-mapi-admin',
    // Path to your entry point. From this file Webpack will begin his work
    entry: [
        "./admin/assets/src/js/ysd-mapi-admin.js",
        "./admin/assets/src/scss/ysd-mapi-admin.scss"
    ],

    // Path and filename of your result bundle.
    // Webpack will bundle all JavaScript into this file
    output: {
        path: path.resolve(__dirname, "admin/assets/dist"),
        filename: "js/ysd-mapi-admin.min.js",
        publicPath: "../"
    },
    module: {
        rules: [{
                test: /\.js$/,
                exclude: /(node_modules)/,
                use: {
                    loader: "babel-loader",
                    options: {
                        presets: ["@babel/preset-env"]
                    }
                }
            },
            {
                // Apply rule for .sass, .scss or .css files
                test: /\.(sa|sc|c)ss$/,
                // Set loaders to transform files.
                // Loaders are applying from right to left(!)
                // The first loader will be applied after others
                use: [{
                        // After all CSS loaders we use plugin to do his work.
                        // It gets all transformed CSS and extracts it into separate
                        // single bundled file
                        loader: MiniCssExtractPlugin.loader
                    },
                    {
                        // This loader resolves url() and @imports inside CSS
                        loader: "css-loader"
                    },
                    {
                        // Then we apply postCSS fixes like autoprefixer and minifying
                        loader: "postcss-loader"
                    },
                    {
                        // First we transform SASS to standard CSS
                        loader: "sass-loader",
                        options: {
                            implementation: require("sass")
                        }
                    }
                ]
            },
            {
                test: /\.(png|jpe?g|gif|svg)$/i,
                use: [{
                    loader: "file-loader",
                    options: {
                        name: "[name].[ext]",
                        outputPath: "images"
                    }
                }]
            }
        ]
    },
    plugins: [
        new webpack.DefinePlugin({
            ENV: JSON.stringify("ysd-mapi-admin")
        }),
        new MiniCssExtractPlugin({
            filename: "css/ysd-mapi-admin.min.css"
        })
    ]
}, {
    name: 'ysd-mapi-main',
    // Path to your entry point. From this file Webpack will begin his work
    entry: [
        "./admin/assets/src/scss/ysd-mapi-main.scss"
    ],

    // Path and filename of your result bundle.
    // Webpack will bundle all JavaScript into this file
    output: {
        path: path.resolve(__dirname, "admin/assets/dist"),
        filename: "js/ysd-mapi-main.min.js",
        publicPath: "../"
    },
    module: {
        rules: [{
            // Apply rule for .sass, .scss or .css files
            test: /\.(sa|sc|c)ss$/,
            // Set loaders to transform files.
            // Loaders are applying from right to left(!)
            // The first loader will be applied after others
            use: [{
                    // After all CSS loaders we use plugin to do his work.
                    // It gets all transformed CSS and extracts it into separate
                    // single bundled file
                    loader: MiniCssExtractPlugin.loader
                },
                {
                    // This loader resolves url() and @imports inside CSS
                    loader: "css-loader"
                },
                {
                    // Then we apply postCSS fixes like autoprefixer and minifying
                    loader: "postcss-loader"
                },
                {
                    // First we transform SASS to standard CSS
                    loader: "sass-loader",
                    options: {
                        implementation: require("sass")
                    }
                }
            ]
        }, {
            test: /\.(png|jpe?g|gif|svg)$/i,
            use: [{
                loader: "file-loader",
                options: {
                    name: "[name].[ext]",
                    outputPath: "images"
                }
            }]
        }]
    },
    plugins: [
        new webpack.DefinePlugin({
            ENV: JSON.stringify("ysd-mapi-main")
        }),
        new MiniCssExtractPlugin({
            filename: "css/ysd-mapi-main.min.css"
        }),
        new RemoveFilesWebpackPlugin({
            after: {
                include: [
                    "./admin/assets/dist/js/ysd-mapi-main.min.js"
                ]
            }
        }),
    ]
}, {
    name: 'ysd-mapi-settings',
    // Path to your entry point. From this file Webpack will begin his work
    entry: [
        "./admin/assets/src/scss/ysd-mapi-settings.scss"
    ],

    // Path and filename of your result bundle.
    // Webpack will bundle all JavaScript into this file
    output: {
        path: path.resolve(__dirname, "admin/assets/dist"),
        filename: "js/ysd-mapi-settings.min.js",
        publicPath: "../"
    },
    module: {
        rules: [{
            // Apply rule for .sass, .scss or .css files
            test: /\.(sa|sc|c)ss$/,
            // Set loaders to transform files.
            // Loaders are applying from right to left(!)
            // The first loader will be applied after others
            use: [{
                    // After all CSS loaders we use plugin to do his work.
                    // It gets all transformed CSS and extracts it into separate
                    // single bundled file
                    loader: MiniCssExtractPlugin.loader
                },
                {
                    // This loader resolves url() and @imports inside CSS
                    loader: "css-loader"
                },
                {
                    // Then we apply postCSS fixes like autoprefixer and minifying
                    loader: "postcss-loader"
                },
                {
                    // First we transform SASS to standard CSS
                    loader: "sass-loader",
                    options: {
                        implementation: require("sass")
                    }
                }
            ]
        }, {
            test: /\.(png|jpe?g|gif|svg)$/i,
            use: [{
                loader: "file-loader",
                options: {
                    name: "[name].[ext]",
                    outputPath: "images"
                }
            }]
        }]
    },
    plugins: [
        new webpack.DefinePlugin({
            ENV: JSON.stringify("ysd-mapi-settings")
        }),
        new MiniCssExtractPlugin({
            filename: "css/ysd-mapi-settings.min.css"
        }),
        new RemoveFilesWebpackPlugin({
            after: {
                include: [
                    "./admin/assets/dist/js/ysd-mapi-settings.min.js"
                ]
            }
        }),
    ]
}, {
    name: 'ysd-mapi-dashboard',
    // Path to your entry point. From this file Webpack will begin his work
    entry: [
        "./admin/assets/src/js/ysd-mapi-dashboard.js"
    ],

    // Path and filename of your result bundle.
    // Webpack will bundle all JavaScript into this file
    output: {
        path: path.resolve(__dirname, "admin/assets/dist"),
        filename: "js/ysd-mapi-dashboard.min.js",
        publicPath: "../"
    },
    module: {
        rules: [{
            test: /\.js$/,
            exclude: /(node_modules)/,
            use: {
                loader: "babel-loader",
                options: {
                    presets: ["@babel/preset-env"]
                }
            }
        }]
    },
    plugins: [
        new webpack.DefinePlugin({
            ENV: JSON.stringify("mapi-default-frontend")
        })
    ]
}, {
    name: "mapi-default-frontend",
    // Path to your entry point. From this file Webpack will begin his work
    entry: ["./front/assets/src/scss/default-frontend.scss"],

    // Path and filename of your result bundle.
    // Webpack will bundle all JavaScript into this file
    output: {
        path: path.resolve(__dirname, "front/assets/dist"),
        filename: "js/default-frontend.min.js",
        publicPath: "../"
    },
    module: {
        rules: [{
            // Apply rule for .sass, .scss or .css files
            test: /\.(sa|sc|c)ss$/,
            // Set loaders to transform files.
            // Loaders are applying from right to left(!)
            // The first loader will be applied after others
            use: [{
                    // After all CSS loaders we use plugin to do his work.
                    // It gets all transformed CSS and extracts it into separate
                    // single bundled file
                    loader: MiniCssExtractPlugin.loader
                },
                {
                    // This loader resolves url() and @imports inside CSS
                    loader: "css-loader"
                },
                {
                    // Then we apply postCSS fixes like autoprefixer and minifying
                    loader: "postcss-loader"
                },
                {
                    // First we transform SASS to standard CSS
                    loader: "sass-loader",
                    options: {
                        implementation: require("sass")
                    }
                }
            ]
        }]
    },
    plugins: [
        new webpack.DefinePlugin({
            ENV: JSON.stringify("mapi-default-frontend")
        }),
        new MiniCssExtractPlugin({
            filename: "css/default-frontend.min.css"
        }),
        new RemoveFilesWebpackPlugin({
            after: {
                include: [
                    "./front/assets/dist/js/default-frontend.min.js"
                ]
            }
        }),
    ]

    // Default mode for Webpack is production.
    // Depending on mode Webpack will apply different things
    // on final bundle. For now we don't need production's JavaScript
    // minifying and other thing so let's set mode to development
    // mode: 'development',
    // watch: true
}];