<?php
use ysdmapi\includes\Autoloader;
use ysdmapi\includes\Activator;
use ysdmapi\includes\Deactivator;
use ysdmapi\includes\Mapi;

/**
 * The plugin bootstrap file
 *
 * The comment block underneath is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, starts the autoloading of classes and
 * defines a function that starts the plugin.
 *
 * @wordpress-plugin
 * Plugin Name:       Yourstyle - MAPI
 * Plugin URI:        https://makelaarsapi.nl/
 * Description:       Display your latest properties with MAPI by Yourstyle.
 * Version:           0.14.58
 * Author:            Yourstyle
 * Author URI:        https://your-style.nl/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       ysd-mapi
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'YSD_MAPI_VERSION', '0.14.58' );

define('YSD_MAPI_PLUGIN_NAME', 'ysd-mapi');
define('YSD_MAPI_TEXT_DOMAIN', 'ysd-mapi');
define('YSD_MAPI_PLUGIN_URL', plugin_dir_url(__FILE__));
define('YSD_MAPI_PLUGIN_PATH', plugin_dir_path(__FILE__));
define('YSD_MAPI_UPLOAD_DIR', wp_get_upload_dir()['basedir'] . '/' . YSD_MAPI_PLUGIN_NAME);
define('YSD_MAPI_PARTIALS_PATH', plugin_dir_path(__FILE__) . 'front/partials');
define('YSD_MAPI_PLUGIN_NICE_NAME', __('Yourstyle - MAPI', YSD_MAPI_TEXT_DOMAIN));
define('MAPI_WPBC_SYMBOL', YSD_MAPI_PLUGIN_URL . 'front/assets/src/images/mapi-wpb-icon.svg');
define('YSD_MAPI_CUSTOM_FIELDS_COMPONENTS',  plugin_dir_path(__FILE__) . 'includes/custom_fields/partials/components');


/**
 * Start the autoloading of php classes
 */
require_once(plugin_dir_path(__FILE__) . 'includes/Autoloader.php');
$autoloader = new Autoloader('ysdmapi', plugin_dir_path(__FILE__));
$autoloader->activate();

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-plugin-name-activator.php
 */
function activate_ysd_mapi() {
	Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-plugin-name-deactivator.php
 */
function deactivate_ysd_mapi() {
	Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_ysd_mapi' );
register_deactivation_hook( __FILE__, 'deactivate_ysd_mapi' );

/**
 * Check if the current theme is a YSP theme.
 *
 * @since 1.0.0
 */
function is_ysp_theme() {

    $response = false;
    $current_theme = wp_get_theme();
    $parent = $current_theme->parent();

    if ( 'Yourstyle+' === $current_theme->name ) {
        $response = true;
    } else if ( !empty($parent) && 'Yourstyle+' === $parent->name ) {
        $response = true;
    }

    return $response;
}

/**
 * Run the user validation check
 *
 * @since    1.0.0
 */
function run_user_validation()
{

    // Require User Valitdation Class
    require_once YSD_MAPI_PLUGIN_PATH. "includes/UserValidation.php";

    $userValidation = new UserValidation();
    $userValidationCheck = UserValidation::check_validation();

    // @todo: fix this
    // return $userValidationCheck;
    return true;

}

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_ysd_mapi() {
    $plugin = new Mapi();
    $plugin->run();
}

run_ysd_mapi();